import * as msRest from "@azure/ms-rest-js";
import * as Models from "../models";
import { ComputeManagementClientContext } from "../computeManagementClientContext";
/** Class representing a SharedGalleryImageVersions. */
export declare class SharedGalleryImageVersions {
    private readonly client;
    /**
     * Create a SharedGalleryImageVersions.
     * @param {ComputeManagementClientContext} client Reference to the service client.
     */
    constructor(client: ComputeManagementClientContext);
    /**
     * List shared gallery image versions by subscription id or tenant id.
     * @param location Resource location.
     * @param galleryUniqueName The unique name of the Shared Gallery.
     * @param galleryImageName The name of the Shared Gallery Image Definition from which the Image
     * Versions are to be listed.
     * @param [options] The optional parameters
     * @returns Promise<Models.SharedGalleryImageVersionsListResponse>
     */
    list(location: string, galleryUniqueName: string, galleryImageName: string, options?: Models.SharedGalleryImageVersionsListOptionalParams): Promise<Models.SharedGalleryImageVersionsListResponse>;
    /**
     * @param location Resource location.
     * @param galleryUniqueName The unique name of the Shared Gallery.
     * @param galleryImageName The name of the Shared Gallery Image Definition from which the Image
     * Versions are to be listed.
     * @param callback The callback
     */
    list(location: string, galleryUniqueName: string, galleryImageName: string, callback: msRest.ServiceCallback<Models.SharedGalleryImageVersionList>): void;
    /**
     * @param location Resource location.
     * @param galleryUniqueName The unique name of the Shared Gallery.
     * @param galleryImageName The name of the Shared Gallery Image Definition from which the Image
     * Versions are to be listed.
     * @param options The optional parameters
     * @param callback The callback
     */
    list(location: string, galleryUniqueName: string, galleryImageName: string, options: Models.SharedGalleryImageVersionsListOptionalParams, callback: msRest.ServiceCallback<Models.SharedGalleryImageVersionList>): void;
    /**
     * Get a shared gallery image version by subscription id or tenant id.
     * @param location Resource location.
     * @param galleryUniqueName The unique name of the Shared Gallery.
     * @param galleryImageName The name of the Shared Gallery Image Definition from which the Image
     * Versions are to be listed.
     * @param galleryImageVersionName The name of the gallery image version to be created. Needs to
     * follow semantic version name pattern: The allowed characters are digit and period. Digits must
     * be within the range of a 32-bit integer. Format: <MajorVersion>.<MinorVersion>.<Patch>
     * @param [options] The optional parameters
     * @returns Promise<Models.SharedGalleryImageVersionsGetResponse>
     */
    get(location: string, galleryUniqueName: string, galleryImageName: string, galleryImageVersionName: string, options?: msRest.RequestOptionsBase): Promise<Models.SharedGalleryImageVersionsGetResponse>;
    /**
     * @param location Resource location.
     * @param galleryUniqueName The unique name of the Shared Gallery.
     * @param galleryImageName The name of the Shared Gallery Image Definition from which the Image
     * Versions are to be listed.
     * @param galleryImageVersionName The name of the gallery image version to be created. Needs to
     * follow semantic version name pattern: The allowed characters are digit and period. Digits must
     * be within the range of a 32-bit integer. Format: <MajorVersion>.<MinorVersion>.<Patch>
     * @param callback The callback
     */
    get(location: string, galleryUniqueName: string, galleryImageName: string, galleryImageVersionName: string, callback: msRest.ServiceCallback<Models.SharedGalleryImageVersion>): void;
    /**
     * @param location Resource location.
     * @param galleryUniqueName The unique name of the Shared Gallery.
     * @param galleryImageName The name of the Shared Gallery Image Definition from which the Image
     * Versions are to be listed.
     * @param galleryImageVersionName The name of the gallery image version to be created. Needs to
     * follow semantic version name pattern: The allowed characters are digit and period. Digits must
     * be within the range of a 32-bit integer. Format: <MajorVersion>.<MinorVersion>.<Patch>
     * @param options The optional parameters
     * @param callback The callback
     */
    get(location: string, galleryUniqueName: string, galleryImageName: string, galleryImageVersionName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.SharedGalleryImageVersion>): void;
    /**
     * List shared gallery image versions by subscription id or tenant id.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.SharedGalleryImageVersionsListNextResponse>
     */
    listNext(nextPageLink: string, options?: Models.SharedGalleryImageVersionsListNextOptionalParams): Promise<Models.SharedGalleryImageVersionsListNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.SharedGalleryImageVersionList>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listNext(nextPageLink: string, options: Models.SharedGalleryImageVersionsListNextOptionalParams, callback: msRest.ServiceCallback<Models.SharedGalleryImageVersionList>): void;
}
//# sourceMappingURL=sharedGalleryImageVersions.d.ts.map