import * as msRest from "@azure/ms-rest-js";
import * as msRestAzure from "@azure/ms-rest-azure-js";
import * as Models from "../models";
import { ComputeManagementClientContext } from "../computeManagementClientContext";
/** Class representing a VirtualMachineScaleSetVMRunCommands. */
export declare class VirtualMachineScaleSetVMRunCommands {
    private readonly client;
    /**
     * Create a VirtualMachineScaleSetVMRunCommands.
     * @param {ComputeManagementClientContext} client Reference to the service client.
     */
    constructor(client: ComputeManagementClientContext);
    /**
     * The operation to create or update the VMSS VM run command.
     * @param resourceGroupName The name of the resource group.
     * @param vmScaleSetName The name of the VM scale set.
     * @param instanceId The instance ID of the virtual machine.
     * @param runCommandName The name of the virtual machine run command.
     * @param runCommand Parameters supplied to the Create Virtual Machine RunCommand operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualMachineScaleSetVMRunCommandsCreateOrUpdateResponse>
     */
    createOrUpdate(resourceGroupName: string, vmScaleSetName: string, instanceId: string, runCommandName: string, runCommand: Models.VirtualMachineRunCommand, options?: msRest.RequestOptionsBase): Promise<Models.VirtualMachineScaleSetVMRunCommandsCreateOrUpdateResponse>;
    /**
     * The operation to update the VMSS VM run command.
     * @param resourceGroupName The name of the resource group.
     * @param vmScaleSetName The name of the VM scale set.
     * @param instanceId The instance ID of the virtual machine.
     * @param runCommandName The name of the virtual machine run command.
     * @param runCommand Parameters supplied to the Update Virtual Machine RunCommand operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualMachineScaleSetVMRunCommandsUpdateResponse>
     */
    update(resourceGroupName: string, vmScaleSetName: string, instanceId: string, runCommandName: string, runCommand: Models.VirtualMachineRunCommandUpdate, options?: msRest.RequestOptionsBase): Promise<Models.VirtualMachineScaleSetVMRunCommandsUpdateResponse>;
    /**
     * The operation to delete the VMSS VM run command.
     * @param resourceGroupName The name of the resource group.
     * @param vmScaleSetName The name of the VM scale set.
     * @param instanceId The instance ID of the virtual machine.
     * @param runCommandName The name of the virtual machine run command.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    deleteMethod(resourceGroupName: string, vmScaleSetName: string, instanceId: string, runCommandName: string, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * The operation to get the VMSS VM run command.
     * @param resourceGroupName The name of the resource group.
     * @param vmScaleSetName The name of the VM scale set.
     * @param instanceId The instance ID of the virtual machine.
     * @param runCommandName The name of the virtual machine run command.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualMachineScaleSetVMRunCommandsGetResponse>
     */
    get(resourceGroupName: string, vmScaleSetName: string, instanceId: string, runCommandName: string, options?: Models.VirtualMachineScaleSetVMRunCommandsGetOptionalParams): Promise<Models.VirtualMachineScaleSetVMRunCommandsGetResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param vmScaleSetName The name of the VM scale set.
     * @param instanceId The instance ID of the virtual machine.
     * @param runCommandName The name of the virtual machine run command.
     * @param callback The callback
     */
    get(resourceGroupName: string, vmScaleSetName: string, instanceId: string, runCommandName: string, callback: msRest.ServiceCallback<Models.VirtualMachineRunCommand>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param vmScaleSetName The name of the VM scale set.
     * @param instanceId The instance ID of the virtual machine.
     * @param runCommandName The name of the virtual machine run command.
     * @param options The optional parameters
     * @param callback The callback
     */
    get(resourceGroupName: string, vmScaleSetName: string, instanceId: string, runCommandName: string, options: Models.VirtualMachineScaleSetVMRunCommandsGetOptionalParams, callback: msRest.ServiceCallback<Models.VirtualMachineRunCommand>): void;
    /**
     * The operation to get all run commands of an instance in Virtual Machine Scaleset.
     * @param resourceGroupName The name of the resource group.
     * @param vmScaleSetName The name of the VM scale set.
     * @param instanceId The instance ID of the virtual machine.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualMachineScaleSetVMRunCommandsListResponse>
     */
    list(resourceGroupName: string, vmScaleSetName: string, instanceId: string, options?: Models.VirtualMachineScaleSetVMRunCommandsListOptionalParams): Promise<Models.VirtualMachineScaleSetVMRunCommandsListResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param vmScaleSetName The name of the VM scale set.
     * @param instanceId The instance ID of the virtual machine.
     * @param callback The callback
     */
    list(resourceGroupName: string, vmScaleSetName: string, instanceId: string, callback: msRest.ServiceCallback<Models.VirtualMachineRunCommandsListResult>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param vmScaleSetName The name of the VM scale set.
     * @param instanceId The instance ID of the virtual machine.
     * @param options The optional parameters
     * @param callback The callback
     */
    list(resourceGroupName: string, vmScaleSetName: string, instanceId: string, options: Models.VirtualMachineScaleSetVMRunCommandsListOptionalParams, callback: msRest.ServiceCallback<Models.VirtualMachineRunCommandsListResult>): void;
    /**
     * The operation to create or update the VMSS VM run command.
     * @param resourceGroupName The name of the resource group.
     * @param vmScaleSetName The name of the VM scale set.
     * @param instanceId The instance ID of the virtual machine.
     * @param runCommandName The name of the virtual machine run command.
     * @param runCommand Parameters supplied to the Create Virtual Machine RunCommand operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginCreateOrUpdate(resourceGroupName: string, vmScaleSetName: string, instanceId: string, runCommandName: string, runCommand: Models.VirtualMachineRunCommand, options?: msRest.RequestOptionsBase): Promise<msRestAzure.LROPoller>;
    /**
     * The operation to update the VMSS VM run command.
     * @param resourceGroupName The name of the resource group.
     * @param vmScaleSetName The name of the VM scale set.
     * @param instanceId The instance ID of the virtual machine.
     * @param runCommandName The name of the virtual machine run command.
     * @param runCommand Parameters supplied to the Update Virtual Machine RunCommand operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginUpdate(resourceGroupName: string, vmScaleSetName: string, instanceId: string, runCommandName: string, runCommand: Models.VirtualMachineRunCommandUpdate, options?: msRest.RequestOptionsBase): Promise<msRestAzure.LROPoller>;
    /**
     * The operation to delete the VMSS VM run command.
     * @param resourceGroupName The name of the resource group.
     * @param vmScaleSetName The name of the VM scale set.
     * @param instanceId The instance ID of the virtual machine.
     * @param runCommandName The name of the virtual machine run command.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginDeleteMethod(resourceGroupName: string, vmScaleSetName: string, instanceId: string, runCommandName: string, options?: msRest.RequestOptionsBase): Promise<msRestAzure.LROPoller>;
    /**
     * The operation to get all run commands of an instance in Virtual Machine Scaleset.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualMachineScaleSetVMRunCommandsListNextResponse>
     */
    listNext(nextPageLink: string, options?: Models.VirtualMachineScaleSetVMRunCommandsListNextOptionalParams): Promise<Models.VirtualMachineScaleSetVMRunCommandsListNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.VirtualMachineRunCommandsListResult>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listNext(nextPageLink: string, options: Models.VirtualMachineScaleSetVMRunCommandsListNextOptionalParams, callback: msRest.ServiceCallback<Models.VirtualMachineRunCommandsListResult>): void;
}
//# sourceMappingURL=virtualMachineScaleSetVMRunCommands.d.ts.map