/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */
import { __assign } from "tslib";
import * as msRest from "@azure/ms-rest-js";
import * as Mappers from "../models/applicationGatewayPrivateEndpointConnectionsMappers";
import * as Parameters from "../models/parameters";
/** Class representing a ApplicationGatewayPrivateEndpointConnections. */
var ApplicationGatewayPrivateEndpointConnections = /** @class */ (function () {
    /**
     * Create a ApplicationGatewayPrivateEndpointConnections.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    function ApplicationGatewayPrivateEndpointConnections(client) {
        this.client = client;
    }
    /**
     * Deletes the specified private endpoint connection on application gateway.
     * @param resourceGroupName The name of the resource group.
     * @param applicationGatewayName The name of the application gateway.
     * @param connectionName The name of the application gateway private endpoint connection.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    ApplicationGatewayPrivateEndpointConnections.prototype.deleteMethod = function (resourceGroupName, applicationGatewayName, connectionName, options) {
        return this.beginDeleteMethod(resourceGroupName, applicationGatewayName, connectionName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Updates the specified private endpoint connection on application gateway.
     * @param resourceGroupName The name of the resource group.
     * @param applicationGatewayName The name of the application gateway.
     * @param connectionName The name of the application gateway private endpoint connection.
     * @param parameters Parameters supplied to update application gateway private endpoint connection
     * operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.ApplicationGatewayPrivateEndpointConnectionsUpdateResponse>
     */
    ApplicationGatewayPrivateEndpointConnections.prototype.update = function (resourceGroupName, applicationGatewayName, connectionName, parameters, options) {
        return this.beginUpdate(resourceGroupName, applicationGatewayName, connectionName, parameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    ApplicationGatewayPrivateEndpointConnections.prototype.get = function (resourceGroupName, applicationGatewayName, connectionName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            applicationGatewayName: applicationGatewayName,
            connectionName: connectionName,
            options: options
        }, getOperationSpec, callback);
    };
    ApplicationGatewayPrivateEndpointConnections.prototype.list = function (resourceGroupName, applicationGatewayName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            applicationGatewayName: applicationGatewayName,
            options: options
        }, listOperationSpec, callback);
    };
    /**
     * Deletes the specified private endpoint connection on application gateway.
     * @param resourceGroupName The name of the resource group.
     * @param applicationGatewayName The name of the application gateway.
     * @param connectionName The name of the application gateway private endpoint connection.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    ApplicationGatewayPrivateEndpointConnections.prototype.beginDeleteMethod = function (resourceGroupName, applicationGatewayName, connectionName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            applicationGatewayName: applicationGatewayName,
            connectionName: connectionName,
            options: options
        }, beginDeleteMethodOperationSpec, options);
    };
    /**
     * Updates the specified private endpoint connection on application gateway.
     * @param resourceGroupName The name of the resource group.
     * @param applicationGatewayName The name of the application gateway.
     * @param connectionName The name of the application gateway private endpoint connection.
     * @param parameters Parameters supplied to update application gateway private endpoint connection
     * operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    ApplicationGatewayPrivateEndpointConnections.prototype.beginUpdate = function (resourceGroupName, applicationGatewayName, connectionName, parameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            applicationGatewayName: applicationGatewayName,
            connectionName: connectionName,
            parameters: parameters,
            options: options
        }, beginUpdateOperationSpec, options);
    };
    ApplicationGatewayPrivateEndpointConnections.prototype.listNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listNextOperationSpec, callback);
    };
    return ApplicationGatewayPrivateEndpointConnections;
}());
export { ApplicationGatewayPrivateEndpointConnections };
// Operation Specifications
var serializer = new msRest.Serializer(Mappers);
var getOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/applicationGateways/{applicationGatewayName}/privateEndpointConnections/{connectionName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.applicationGatewayName,
        Parameters.connectionName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ApplicationGatewayPrivateEndpointConnection
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/applicationGateways/{applicationGatewayName}/privateEndpointConnections",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.applicationGatewayName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ApplicationGatewayPrivateEndpointConnectionListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginDeleteMethodOperationSpec = {
    httpMethod: "DELETE",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/applicationGateways/{applicationGatewayName}/privateEndpointConnections/{connectionName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.applicationGatewayName,
        Parameters.connectionName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {},
        202: {},
        204: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginUpdateOperationSpec = {
    httpMethod: "PUT",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/applicationGateways/{applicationGatewayName}/privateEndpointConnections/{connectionName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.applicationGatewayName,
        Parameters.connectionName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.ApplicationGatewayPrivateEndpointConnection), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.ApplicationGatewayPrivateEndpointConnection
        },
        202: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ApplicationGatewayPrivateEndpointConnectionListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
//# sourceMappingURL=applicationGatewayPrivateEndpointConnections.js.map