/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */
import { __assign } from "tslib";
import * as msRest from "@azure/ms-rest-js";
import * as Mappers from "../models/expressRouteCircuitAuthorizationsMappers";
import * as Parameters from "../models/parameters";
/** Class representing a ExpressRouteCircuitAuthorizations. */
var ExpressRouteCircuitAuthorizations = /** @class */ (function () {
    /**
     * Create a ExpressRouteCircuitAuthorizations.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    function ExpressRouteCircuitAuthorizations(client) {
        this.client = client;
    }
    /**
     * Deletes the specified authorization from the specified express route circuit.
     * @param resourceGroupName The name of the resource group.
     * @param circuitName The name of the express route circuit.
     * @param authorizationName The name of the authorization.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    ExpressRouteCircuitAuthorizations.prototype.deleteMethod = function (resourceGroupName, circuitName, authorizationName, options) {
        return this.beginDeleteMethod(resourceGroupName, circuitName, authorizationName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    ExpressRouteCircuitAuthorizations.prototype.get = function (resourceGroupName, circuitName, authorizationName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            circuitName: circuitName,
            authorizationName: authorizationName,
            options: options
        }, getOperationSpec, callback);
    };
    /**
     * Creates or updates an authorization in the specified express route circuit.
     * @param resourceGroupName The name of the resource group.
     * @param circuitName The name of the express route circuit.
     * @param authorizationName The name of the authorization.
     * @param authorizationParameters Parameters supplied to the create or update express route circuit
     * authorization operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.ExpressRouteCircuitAuthorizationsCreateOrUpdateResponse>
     */
    ExpressRouteCircuitAuthorizations.prototype.createOrUpdate = function (resourceGroupName, circuitName, authorizationName, authorizationParameters, options) {
        return this.beginCreateOrUpdate(resourceGroupName, circuitName, authorizationName, authorizationParameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    ExpressRouteCircuitAuthorizations.prototype.list = function (resourceGroupName, circuitName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            circuitName: circuitName,
            options: options
        }, listOperationSpec, callback);
    };
    /**
     * Deletes the specified authorization from the specified express route circuit.
     * @param resourceGroupName The name of the resource group.
     * @param circuitName The name of the express route circuit.
     * @param authorizationName The name of the authorization.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    ExpressRouteCircuitAuthorizations.prototype.beginDeleteMethod = function (resourceGroupName, circuitName, authorizationName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            circuitName: circuitName,
            authorizationName: authorizationName,
            options: options
        }, beginDeleteMethodOperationSpec, options);
    };
    /**
     * Creates or updates an authorization in the specified express route circuit.
     * @param resourceGroupName The name of the resource group.
     * @param circuitName The name of the express route circuit.
     * @param authorizationName The name of the authorization.
     * @param authorizationParameters Parameters supplied to the create or update express route circuit
     * authorization operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    ExpressRouteCircuitAuthorizations.prototype.beginCreateOrUpdate = function (resourceGroupName, circuitName, authorizationName, authorizationParameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            circuitName: circuitName,
            authorizationName: authorizationName,
            authorizationParameters: authorizationParameters,
            options: options
        }, beginCreateOrUpdateOperationSpec, options);
    };
    ExpressRouteCircuitAuthorizations.prototype.listNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listNextOperationSpec, callback);
    };
    return ExpressRouteCircuitAuthorizations;
}());
export { ExpressRouteCircuitAuthorizations };
// Operation Specifications
var serializer = new msRest.Serializer(Mappers);
var getOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/expressRouteCircuits/{circuitName}/authorizations/{authorizationName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.circuitName,
        Parameters.authorizationName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ExpressRouteCircuitAuthorization
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/expressRouteCircuits/{circuitName}/authorizations",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.circuitName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.AuthorizationListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginDeleteMethodOperationSpec = {
    httpMethod: "DELETE",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/expressRouteCircuits/{circuitName}/authorizations/{authorizationName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.circuitName,
        Parameters.authorizationName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {},
        202: {},
        204: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginCreateOrUpdateOperationSpec = {
    httpMethod: "PUT",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/expressRouteCircuits/{circuitName}/authorizations/{authorizationName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.circuitName,
        Parameters.authorizationName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "authorizationParameters",
        mapper: __assign(__assign({}, Mappers.ExpressRouteCircuitAuthorization), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.ExpressRouteCircuitAuthorization
        },
        201: {
            bodyMapper: Mappers.ExpressRouteCircuitAuthorization
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.AuthorizationListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
//# sourceMappingURL=expressRouteCircuitAuthorizations.js.map