/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */
import { __assign } from "tslib";
import * as msRest from "@azure/ms-rest-js";
import * as Mappers from "../models/expressRouteCircuitPeeringsMappers";
import * as Parameters from "../models/parameters";
/** Class representing a ExpressRouteCircuitPeerings. */
var ExpressRouteCircuitPeerings = /** @class */ (function () {
    /**
     * Create a ExpressRouteCircuitPeerings.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    function ExpressRouteCircuitPeerings(client) {
        this.client = client;
    }
    /**
     * Deletes the specified peering from the specified express route circuit.
     * @param resourceGroupName The name of the resource group.
     * @param circuitName The name of the express route circuit.
     * @param peeringName The name of the peering.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    ExpressRouteCircuitPeerings.prototype.deleteMethod = function (resourceGroupName, circuitName, peeringName, options) {
        return this.beginDeleteMethod(resourceGroupName, circuitName, peeringName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    ExpressRouteCircuitPeerings.prototype.get = function (resourceGroupName, circuitName, peeringName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            circuitName: circuitName,
            peeringName: peeringName,
            options: options
        }, getOperationSpec, callback);
    };
    /**
     * Creates or updates a peering in the specified express route circuits.
     * @param resourceGroupName The name of the resource group.
     * @param circuitName The name of the express route circuit.
     * @param peeringName The name of the peering.
     * @param peeringParameters Parameters supplied to the create or update express route circuit
     * peering operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.ExpressRouteCircuitPeeringsCreateOrUpdateResponse>
     */
    ExpressRouteCircuitPeerings.prototype.createOrUpdate = function (resourceGroupName, circuitName, peeringName, peeringParameters, options) {
        return this.beginCreateOrUpdate(resourceGroupName, circuitName, peeringName, peeringParameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    ExpressRouteCircuitPeerings.prototype.list = function (resourceGroupName, circuitName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            circuitName: circuitName,
            options: options
        }, listOperationSpec, callback);
    };
    /**
     * Deletes the specified peering from the specified express route circuit.
     * @param resourceGroupName The name of the resource group.
     * @param circuitName The name of the express route circuit.
     * @param peeringName The name of the peering.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    ExpressRouteCircuitPeerings.prototype.beginDeleteMethod = function (resourceGroupName, circuitName, peeringName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            circuitName: circuitName,
            peeringName: peeringName,
            options: options
        }, beginDeleteMethodOperationSpec, options);
    };
    /**
     * Creates or updates a peering in the specified express route circuits.
     * @param resourceGroupName The name of the resource group.
     * @param circuitName The name of the express route circuit.
     * @param peeringName The name of the peering.
     * @param peeringParameters Parameters supplied to the create or update express route circuit
     * peering operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    ExpressRouteCircuitPeerings.prototype.beginCreateOrUpdate = function (resourceGroupName, circuitName, peeringName, peeringParameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            circuitName: circuitName,
            peeringName: peeringName,
            peeringParameters: peeringParameters,
            options: options
        }, beginCreateOrUpdateOperationSpec, options);
    };
    ExpressRouteCircuitPeerings.prototype.listNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listNextOperationSpec, callback);
    };
    return ExpressRouteCircuitPeerings;
}());
export { ExpressRouteCircuitPeerings };
// Operation Specifications
var serializer = new msRest.Serializer(Mappers);
var getOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/expressRouteCircuits/{circuitName}/peerings/{peeringName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.circuitName,
        Parameters.peeringName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ExpressRouteCircuitPeering
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/expressRouteCircuits/{circuitName}/peerings",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.circuitName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ExpressRouteCircuitPeeringListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginDeleteMethodOperationSpec = {
    httpMethod: "DELETE",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/expressRouteCircuits/{circuitName}/peerings/{peeringName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.circuitName,
        Parameters.peeringName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {},
        202: {},
        204: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginCreateOrUpdateOperationSpec = {
    httpMethod: "PUT",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/expressRouteCircuits/{circuitName}/peerings/{peeringName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.circuitName,
        Parameters.peeringName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "peeringParameters",
        mapper: __assign(__assign({}, Mappers.ExpressRouteCircuitPeering), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.ExpressRouteCircuitPeering
        },
        201: {
            bodyMapper: Mappers.ExpressRouteCircuitPeering
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ExpressRouteCircuitPeeringListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
//# sourceMappingURL=expressRouteCircuitPeerings.js.map