/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */
import { __assign } from "tslib";
import * as msRest from "@azure/ms-rest-js";
import * as Mappers from "../models/expressRouteConnectionsMappers";
import * as Parameters from "../models/parameters";
/** Class representing a ExpressRouteConnections. */
var ExpressRouteConnections = /** @class */ (function () {
    /**
     * Create a ExpressRouteConnections.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    function ExpressRouteConnections(client) {
        this.client = client;
    }
    /**
     * Creates a connection between an ExpressRoute gateway and an ExpressRoute circuit.
     * @param resourceGroupName The name of the resource group.
     * @param expressRouteGatewayName The name of the ExpressRoute gateway.
     * @param connectionName The name of the connection subresource.
     * @param putExpressRouteConnectionParameters Parameters required in an ExpressRouteConnection PUT
     * operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.ExpressRouteConnectionsCreateOrUpdateResponse>
     */
    ExpressRouteConnections.prototype.createOrUpdate = function (resourceGroupName, expressRouteGatewayName, connectionName, putExpressRouteConnectionParameters, options) {
        return this.beginCreateOrUpdate(resourceGroupName, expressRouteGatewayName, connectionName, putExpressRouteConnectionParameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    ExpressRouteConnections.prototype.get = function (resourceGroupName, expressRouteGatewayName, connectionName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            expressRouteGatewayName: expressRouteGatewayName,
            connectionName: connectionName,
            options: options
        }, getOperationSpec, callback);
    };
    /**
     * Deletes a connection to a ExpressRoute circuit.
     * @param resourceGroupName The name of the resource group.
     * @param expressRouteGatewayName The name of the ExpressRoute gateway.
     * @param connectionName The name of the connection subresource.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    ExpressRouteConnections.prototype.deleteMethod = function (resourceGroupName, expressRouteGatewayName, connectionName, options) {
        return this.beginDeleteMethod(resourceGroupName, expressRouteGatewayName, connectionName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    ExpressRouteConnections.prototype.list = function (resourceGroupName, expressRouteGatewayName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            expressRouteGatewayName: expressRouteGatewayName,
            options: options
        }, listOperationSpec, callback);
    };
    /**
     * Creates a connection between an ExpressRoute gateway and an ExpressRoute circuit.
     * @param resourceGroupName The name of the resource group.
     * @param expressRouteGatewayName The name of the ExpressRoute gateway.
     * @param connectionName The name of the connection subresource.
     * @param putExpressRouteConnectionParameters Parameters required in an ExpressRouteConnection PUT
     * operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    ExpressRouteConnections.prototype.beginCreateOrUpdate = function (resourceGroupName, expressRouteGatewayName, connectionName, putExpressRouteConnectionParameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            expressRouteGatewayName: expressRouteGatewayName,
            connectionName: connectionName,
            putExpressRouteConnectionParameters: putExpressRouteConnectionParameters,
            options: options
        }, beginCreateOrUpdateOperationSpec, options);
    };
    /**
     * Deletes a connection to a ExpressRoute circuit.
     * @param resourceGroupName The name of the resource group.
     * @param expressRouteGatewayName The name of the ExpressRoute gateway.
     * @param connectionName The name of the connection subresource.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    ExpressRouteConnections.prototype.beginDeleteMethod = function (resourceGroupName, expressRouteGatewayName, connectionName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            expressRouteGatewayName: expressRouteGatewayName,
            connectionName: connectionName,
            options: options
        }, beginDeleteMethodOperationSpec, options);
    };
    return ExpressRouteConnections;
}());
export { ExpressRouteConnections };
// Operation Specifications
var serializer = new msRest.Serializer(Mappers);
var getOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/expressRouteGateways/{expressRouteGatewayName}/expressRouteConnections/{connectionName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.expressRouteGatewayName,
        Parameters.connectionName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ExpressRouteConnection
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/expressRouteGateways/{expressRouteGatewayName}/expressRouteConnections",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.expressRouteGatewayName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ExpressRouteConnectionList
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginCreateOrUpdateOperationSpec = {
    httpMethod: "PUT",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/expressRouteGateways/{expressRouteGatewayName}/expressRouteConnections/{connectionName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.expressRouteGatewayName,
        Parameters.connectionName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "putExpressRouteConnectionParameters",
        mapper: __assign(__assign({}, Mappers.ExpressRouteConnection), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.ExpressRouteConnection
        },
        201: {
            bodyMapper: Mappers.ExpressRouteConnection
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginDeleteMethodOperationSpec = {
    httpMethod: "DELETE",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/expressRouteGateways/{expressRouteGatewayName}/expressRouteConnections/{connectionName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.expressRouteGatewayName,
        Parameters.connectionName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {},
        202: {},
        204: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
//# sourceMappingURL=expressRouteConnections.js.map