/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */
import { __assign } from "tslib";
import * as msRest from "@azure/ms-rest-js";
import * as Mappers from "../models/expressRouteGatewaysMappers";
import * as Parameters from "../models/parameters";
/** Class representing a ExpressRouteGateways. */
var ExpressRouteGateways = /** @class */ (function () {
    /**
     * Create a ExpressRouteGateways.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    function ExpressRouteGateways(client) {
        this.client = client;
    }
    ExpressRouteGateways.prototype.listBySubscription = function (options, callback) {
        return this.client.sendOperationRequest({
            options: options
        }, listBySubscriptionOperationSpec, callback);
    };
    ExpressRouteGateways.prototype.listByResourceGroup = function (resourceGroupName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            options: options
        }, listByResourceGroupOperationSpec, callback);
    };
    /**
     * Creates or updates a ExpressRoute gateway in a specified resource group.
     * @param resourceGroupName The name of the resource group.
     * @param expressRouteGatewayName The name of the ExpressRoute gateway.
     * @param putExpressRouteGatewayParameters Parameters required in an ExpressRoute gateway PUT
     * operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.ExpressRouteGatewaysCreateOrUpdateResponse>
     */
    ExpressRouteGateways.prototype.createOrUpdate = function (resourceGroupName, expressRouteGatewayName, putExpressRouteGatewayParameters, options) {
        return this.beginCreateOrUpdate(resourceGroupName, expressRouteGatewayName, putExpressRouteGatewayParameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Updates express route gateway tags.
     * @param resourceGroupName The resource group name of the ExpressRouteGateway.
     * @param expressRouteGatewayName The name of the gateway.
     * @param expressRouteGatewayParameters Parameters supplied to update a virtual wan express route
     * gateway tags.
     * @param [options] The optional parameters
     * @returns Promise<Models.ExpressRouteGatewaysUpdateTagsResponse>
     */
    ExpressRouteGateways.prototype.updateTags = function (resourceGroupName, expressRouteGatewayName, expressRouteGatewayParameters, options) {
        return this.beginUpdateTags(resourceGroupName, expressRouteGatewayName, expressRouteGatewayParameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    ExpressRouteGateways.prototype.get = function (resourceGroupName, expressRouteGatewayName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            expressRouteGatewayName: expressRouteGatewayName,
            options: options
        }, getOperationSpec, callback);
    };
    /**
     * Deletes the specified ExpressRoute gateway in a resource group. An ExpressRoute gateway resource
     * can only be deleted when there are no connection subresources.
     * @param resourceGroupName The name of the resource group.
     * @param expressRouteGatewayName The name of the ExpressRoute gateway.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    ExpressRouteGateways.prototype.deleteMethod = function (resourceGroupName, expressRouteGatewayName, options) {
        return this.beginDeleteMethod(resourceGroupName, expressRouteGatewayName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Creates or updates a ExpressRoute gateway in a specified resource group.
     * @param resourceGroupName The name of the resource group.
     * @param expressRouteGatewayName The name of the ExpressRoute gateway.
     * @param putExpressRouteGatewayParameters Parameters required in an ExpressRoute gateway PUT
     * operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    ExpressRouteGateways.prototype.beginCreateOrUpdate = function (resourceGroupName, expressRouteGatewayName, putExpressRouteGatewayParameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            expressRouteGatewayName: expressRouteGatewayName,
            putExpressRouteGatewayParameters: putExpressRouteGatewayParameters,
            options: options
        }, beginCreateOrUpdateOperationSpec, options);
    };
    /**
     * Updates express route gateway tags.
     * @param resourceGroupName The resource group name of the ExpressRouteGateway.
     * @param expressRouteGatewayName The name of the gateway.
     * @param expressRouteGatewayParameters Parameters supplied to update a virtual wan express route
     * gateway tags.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    ExpressRouteGateways.prototype.beginUpdateTags = function (resourceGroupName, expressRouteGatewayName, expressRouteGatewayParameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            expressRouteGatewayName: expressRouteGatewayName,
            expressRouteGatewayParameters: expressRouteGatewayParameters,
            options: options
        }, beginUpdateTagsOperationSpec, options);
    };
    /**
     * Deletes the specified ExpressRoute gateway in a resource group. An ExpressRoute gateway resource
     * can only be deleted when there are no connection subresources.
     * @param resourceGroupName The name of the resource group.
     * @param expressRouteGatewayName The name of the ExpressRoute gateway.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    ExpressRouteGateways.prototype.beginDeleteMethod = function (resourceGroupName, expressRouteGatewayName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            expressRouteGatewayName: expressRouteGatewayName,
            options: options
        }, beginDeleteMethodOperationSpec, options);
    };
    return ExpressRouteGateways;
}());
export { ExpressRouteGateways };
// Operation Specifications
var serializer = new msRest.Serializer(Mappers);
var listBySubscriptionOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/providers/Microsoft.Network/expressRouteGateways",
    urlParameters: [
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ExpressRouteGatewayList
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listByResourceGroupOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/expressRouteGateways",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ExpressRouteGatewayList
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var getOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/expressRouteGateways/{expressRouteGatewayName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.expressRouteGatewayName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ExpressRouteGateway
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginCreateOrUpdateOperationSpec = {
    httpMethod: "PUT",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/expressRouteGateways/{expressRouteGatewayName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.expressRouteGatewayName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "putExpressRouteGatewayParameters",
        mapper: __assign(__assign({}, Mappers.ExpressRouteGateway), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.ExpressRouteGateway
        },
        201: {
            bodyMapper: Mappers.ExpressRouteGateway
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginUpdateTagsOperationSpec = {
    httpMethod: "PATCH",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/expressRouteGateways/{expressRouteGatewayName}",
    urlParameters: [
        Parameters.subscriptionId,
        Parameters.resourceGroupName,
        Parameters.expressRouteGatewayName
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "expressRouteGatewayParameters",
        mapper: __assign(__assign({}, Mappers.TagsObject), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.ExpressRouteGateway
        },
        202: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginDeleteMethodOperationSpec = {
    httpMethod: "DELETE",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/expressRouteGateways/{expressRouteGatewayName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.expressRouteGatewayName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {},
        202: {},
        204: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
//# sourceMappingURL=expressRouteGateways.js.map