/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */
import { __assign } from "tslib";
import * as msRest from "@azure/ms-rest-js";
import * as Mappers from "../models/inboundSecurityRuleOperationsMappers";
import * as Parameters from "../models/parameters";
/** Class representing a InboundSecurityRuleOperations. */
var InboundSecurityRuleOperations = /** @class */ (function () {
    /**
     * Create a InboundSecurityRuleOperations.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    function InboundSecurityRuleOperations(client) {
        this.client = client;
    }
    /**
     * Creates or updates the specified Network Virtual Appliance Inbound Security Rules.
     * @param resourceGroupName The name of the resource group.
     * @param networkVirtualApplianceName The name of the Network Virtual Appliance.
     * @param ruleCollectionName The name of security rule collection.
     * @param parameters Parameters supplied to the create or update Network Virtual Appliance Inbound
     * Security Rules operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.InboundSecurityRuleCreateOrUpdateResponse>
     */
    InboundSecurityRuleOperations.prototype.createOrUpdate = function (resourceGroupName, networkVirtualApplianceName, ruleCollectionName, parameters, options) {
        return this.beginCreateOrUpdate(resourceGroupName, networkVirtualApplianceName, ruleCollectionName, parameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Creates or updates the specified Network Virtual Appliance Inbound Security Rules.
     * @param resourceGroupName The name of the resource group.
     * @param networkVirtualApplianceName The name of the Network Virtual Appliance.
     * @param ruleCollectionName The name of security rule collection.
     * @param parameters Parameters supplied to the create or update Network Virtual Appliance Inbound
     * Security Rules operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    InboundSecurityRuleOperations.prototype.beginCreateOrUpdate = function (resourceGroupName, networkVirtualApplianceName, ruleCollectionName, parameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            networkVirtualApplianceName: networkVirtualApplianceName,
            ruleCollectionName: ruleCollectionName,
            parameters: parameters,
            options: options
        }, beginCreateOrUpdateOperationSpec, options);
    };
    return InboundSecurityRuleOperations;
}());
export { InboundSecurityRuleOperations };
// Operation Specifications
var serializer = new msRest.Serializer(Mappers);
var beginCreateOrUpdateOperationSpec = {
    httpMethod: "PUT",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/networkVirtualAppliances/{networkVirtualApplianceName}/inboundSecurityRules/{ruleCollectionName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.networkVirtualApplianceName,
        Parameters.ruleCollectionName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.InboundSecurityRule), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.InboundSecurityRule
        },
        201: {
            bodyMapper: Mappers.InboundSecurityRule
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
//# sourceMappingURL=inboundSecurityRuleOperations.js.map