/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */
import { __assign } from "tslib";
import * as msRest from "@azure/ms-rest-js";
import * as Mappers from "../models/localNetworkGatewaysMappers";
import * as Parameters from "../models/parameters";
/** Class representing a LocalNetworkGateways. */
var LocalNetworkGateways = /** @class */ (function () {
    /**
     * Create a LocalNetworkGateways.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    function LocalNetworkGateways(client) {
        this.client = client;
    }
    /**
     * Creates or updates a local network gateway in the specified resource group.
     * @param resourceGroupName The name of the resource group.
     * @param localNetworkGatewayName The name of the local network gateway.
     * @param parameters Parameters supplied to the create or update local network gateway operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.LocalNetworkGatewaysCreateOrUpdateResponse>
     */
    LocalNetworkGateways.prototype.createOrUpdate = function (resourceGroupName, localNetworkGatewayName, parameters, options) {
        return this.beginCreateOrUpdate(resourceGroupName, localNetworkGatewayName, parameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    LocalNetworkGateways.prototype.get = function (resourceGroupName, localNetworkGatewayName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            localNetworkGatewayName: localNetworkGatewayName,
            options: options
        }, getOperationSpec, callback);
    };
    /**
     * Deletes the specified local network gateway.
     * @param resourceGroupName The name of the resource group.
     * @param localNetworkGatewayName The name of the local network gateway.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    LocalNetworkGateways.prototype.deleteMethod = function (resourceGroupName, localNetworkGatewayName, options) {
        return this.beginDeleteMethod(resourceGroupName, localNetworkGatewayName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    LocalNetworkGateways.prototype.updateTags = function (resourceGroupName, localNetworkGatewayName, parameters, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            localNetworkGatewayName: localNetworkGatewayName,
            parameters: parameters,
            options: options
        }, updateTagsOperationSpec, callback);
    };
    LocalNetworkGateways.prototype.list = function (resourceGroupName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            options: options
        }, listOperationSpec, callback);
    };
    /**
     * Creates or updates a local network gateway in the specified resource group.
     * @param resourceGroupName The name of the resource group.
     * @param localNetworkGatewayName The name of the local network gateway.
     * @param parameters Parameters supplied to the create or update local network gateway operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    LocalNetworkGateways.prototype.beginCreateOrUpdate = function (resourceGroupName, localNetworkGatewayName, parameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            localNetworkGatewayName: localNetworkGatewayName,
            parameters: parameters,
            options: options
        }, beginCreateOrUpdateOperationSpec, options);
    };
    /**
     * Deletes the specified local network gateway.
     * @param resourceGroupName The name of the resource group.
     * @param localNetworkGatewayName The name of the local network gateway.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    LocalNetworkGateways.prototype.beginDeleteMethod = function (resourceGroupName, localNetworkGatewayName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            localNetworkGatewayName: localNetworkGatewayName,
            options: options
        }, beginDeleteMethodOperationSpec, options);
    };
    LocalNetworkGateways.prototype.listNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listNextOperationSpec, callback);
    };
    return LocalNetworkGateways;
}());
export { LocalNetworkGateways };
// Operation Specifications
var serializer = new msRest.Serializer(Mappers);
var getOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/localNetworkGateways/{localNetworkGatewayName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.localNetworkGatewayName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.LocalNetworkGateway
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var updateTagsOperationSpec = {
    httpMethod: "PATCH",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/localNetworkGateways/{localNetworkGatewayName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.localNetworkGatewayName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.TagsObject), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.LocalNetworkGateway
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/localNetworkGateways",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.LocalNetworkGatewayListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginCreateOrUpdateOperationSpec = {
    httpMethod: "PUT",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/localNetworkGateways/{localNetworkGatewayName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.localNetworkGatewayName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.LocalNetworkGateway), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.LocalNetworkGateway
        },
        201: {
            bodyMapper: Mappers.LocalNetworkGateway
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginDeleteMethodOperationSpec = {
    httpMethod: "DELETE",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/localNetworkGateways/{localNetworkGatewayName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.localNetworkGatewayName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {},
        202: {},
        204: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.LocalNetworkGatewayListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
//# sourceMappingURL=localNetworkGateways.js.map