/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */
import { __assign } from "tslib";
import * as msRest from "@azure/ms-rest-js";
import * as Mappers from "../models/routeFilterRulesMappers";
import * as Parameters from "../models/parameters";
/** Class representing a RouteFilterRules. */
var RouteFilterRules = /** @class */ (function () {
    /**
     * Create a RouteFilterRules.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    function RouteFilterRules(client) {
        this.client = client;
    }
    /**
     * Deletes the specified rule from a route filter.
     * @param resourceGroupName The name of the resource group.
     * @param routeFilterName The name of the route filter.
     * @param ruleName The name of the rule.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    RouteFilterRules.prototype.deleteMethod = function (resourceGroupName, routeFilterName, ruleName, options) {
        return this.beginDeleteMethod(resourceGroupName, routeFilterName, ruleName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    RouteFilterRules.prototype.get = function (resourceGroupName, routeFilterName, ruleName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            routeFilterName: routeFilterName,
            ruleName: ruleName,
            options: options
        }, getOperationSpec, callback);
    };
    /**
     * Creates or updates a route in the specified route filter.
     * @param resourceGroupName The name of the resource group.
     * @param routeFilterName The name of the route filter.
     * @param ruleName The name of the route filter rule.
     * @param routeFilterRuleParameters Parameters supplied to the create or update route filter rule
     * operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.RouteFilterRulesCreateOrUpdateResponse>
     */
    RouteFilterRules.prototype.createOrUpdate = function (resourceGroupName, routeFilterName, ruleName, routeFilterRuleParameters, options) {
        return this.beginCreateOrUpdate(resourceGroupName, routeFilterName, ruleName, routeFilterRuleParameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    RouteFilterRules.prototype.listByRouteFilter = function (resourceGroupName, routeFilterName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            routeFilterName: routeFilterName,
            options: options
        }, listByRouteFilterOperationSpec, callback);
    };
    /**
     * Deletes the specified rule from a route filter.
     * @param resourceGroupName The name of the resource group.
     * @param routeFilterName The name of the route filter.
     * @param ruleName The name of the rule.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    RouteFilterRules.prototype.beginDeleteMethod = function (resourceGroupName, routeFilterName, ruleName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            routeFilterName: routeFilterName,
            ruleName: ruleName,
            options: options
        }, beginDeleteMethodOperationSpec, options);
    };
    /**
     * Creates or updates a route in the specified route filter.
     * @param resourceGroupName The name of the resource group.
     * @param routeFilterName The name of the route filter.
     * @param ruleName The name of the route filter rule.
     * @param routeFilterRuleParameters Parameters supplied to the create or update route filter rule
     * operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    RouteFilterRules.prototype.beginCreateOrUpdate = function (resourceGroupName, routeFilterName, ruleName, routeFilterRuleParameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            routeFilterName: routeFilterName,
            ruleName: ruleName,
            routeFilterRuleParameters: routeFilterRuleParameters,
            options: options
        }, beginCreateOrUpdateOperationSpec, options);
    };
    RouteFilterRules.prototype.listByRouteFilterNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listByRouteFilterNextOperationSpec, callback);
    };
    return RouteFilterRules;
}());
export { RouteFilterRules };
// Operation Specifications
var serializer = new msRest.Serializer(Mappers);
var getOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/routeFilters/{routeFilterName}/routeFilterRules/{ruleName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.routeFilterName,
        Parameters.ruleName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.RouteFilterRule
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listByRouteFilterOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/routeFilters/{routeFilterName}/routeFilterRules",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.routeFilterName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.RouteFilterRuleListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginDeleteMethodOperationSpec = {
    httpMethod: "DELETE",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/routeFilters/{routeFilterName}/routeFilterRules/{ruleName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.routeFilterName,
        Parameters.ruleName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {},
        202: {},
        204: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginCreateOrUpdateOperationSpec = {
    httpMethod: "PUT",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/routeFilters/{routeFilterName}/routeFilterRules/{ruleName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.routeFilterName,
        Parameters.ruleName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "routeFilterRuleParameters",
        mapper: __assign(__assign({}, Mappers.RouteFilterRule), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.RouteFilterRule
        },
        201: {
            bodyMapper: Mappers.RouteFilterRule
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listByRouteFilterNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.RouteFilterRuleListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
//# sourceMappingURL=routeFilterRules.js.map