import * as msRest from "@azure/ms-rest-js";
import * as msRestAzure from "@azure/ms-rest-azure-js";
import * as Models from "../models";
import { NetworkManagementClientContext } from "../networkManagementClientContext";
/** Class representing a VirtualApplianceSites. */
export declare class VirtualApplianceSites {
    private readonly client;
    /**
     * Create a VirtualApplianceSites.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    constructor(client: NetworkManagementClientContext);
    /**
     * Deletes the specified site from a Virtual Appliance.
     * @param resourceGroupName The name of the resource group.
     * @param networkVirtualApplianceName The name of the Network Virtual Appliance.
     * @param siteName The name of the site.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    deleteMethod(resourceGroupName: string, networkVirtualApplianceName: string, siteName: string, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * Gets the specified Virtual Appliance Site.
     * @param resourceGroupName The name of the resource group.
     * @param networkVirtualApplianceName The name of the Network Virtual Appliance.
     * @param siteName The name of the site.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualApplianceSitesGetResponse>
     */
    get(resourceGroupName: string, networkVirtualApplianceName: string, siteName: string, options?: msRest.RequestOptionsBase): Promise<Models.VirtualApplianceSitesGetResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param networkVirtualApplianceName The name of the Network Virtual Appliance.
     * @param siteName The name of the site.
     * @param callback The callback
     */
    get(resourceGroupName: string, networkVirtualApplianceName: string, siteName: string, callback: msRest.ServiceCallback<Models.VirtualApplianceSite>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param networkVirtualApplianceName The name of the Network Virtual Appliance.
     * @param siteName The name of the site.
     * @param options The optional parameters
     * @param callback The callback
     */
    get(resourceGroupName: string, networkVirtualApplianceName: string, siteName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.VirtualApplianceSite>): void;
    /**
     * Creates or updates the specified Network Virtual Appliance Site.
     * @param resourceGroupName The name of the resource group.
     * @param networkVirtualApplianceName The name of the Network Virtual Appliance.
     * @param siteName The name of the site.
     * @param parameters Parameters supplied to the create or update Network Virtual Appliance Site
     * operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualApplianceSitesCreateOrUpdateResponse>
     */
    createOrUpdate(resourceGroupName: string, networkVirtualApplianceName: string, siteName: string, parameters: Models.VirtualApplianceSite, options?: msRest.RequestOptionsBase): Promise<Models.VirtualApplianceSitesCreateOrUpdateResponse>;
    /**
     * Lists all Network Virtual Appliance Sites in a Network Virtual Appliance resource.
     * @param resourceGroupName The name of the resource group.
     * @param networkVirtualApplianceName The name of the Network Virtual Appliance.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualApplianceSitesListResponse>
     */
    list(resourceGroupName: string, networkVirtualApplianceName: string, options?: msRest.RequestOptionsBase): Promise<Models.VirtualApplianceSitesListResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param networkVirtualApplianceName The name of the Network Virtual Appliance.
     * @param callback The callback
     */
    list(resourceGroupName: string, networkVirtualApplianceName: string, callback: msRest.ServiceCallback<Models.NetworkVirtualApplianceSiteListResult>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param networkVirtualApplianceName The name of the Network Virtual Appliance.
     * @param options The optional parameters
     * @param callback The callback
     */
    list(resourceGroupName: string, networkVirtualApplianceName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.NetworkVirtualApplianceSiteListResult>): void;
    /**
     * Deletes the specified site from a Virtual Appliance.
     * @param resourceGroupName The name of the resource group.
     * @param networkVirtualApplianceName The name of the Network Virtual Appliance.
     * @param siteName The name of the site.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginDeleteMethod(resourceGroupName: string, networkVirtualApplianceName: string, siteName: string, options?: msRest.RequestOptionsBase): Promise<msRestAzure.LROPoller>;
    /**
     * Creates or updates the specified Network Virtual Appliance Site.
     * @param resourceGroupName The name of the resource group.
     * @param networkVirtualApplianceName The name of the Network Virtual Appliance.
     * @param siteName The name of the site.
     * @param parameters Parameters supplied to the create or update Network Virtual Appliance Site
     * operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginCreateOrUpdate(resourceGroupName: string, networkVirtualApplianceName: string, siteName: string, parameters: Models.VirtualApplianceSite, options?: msRest.RequestOptionsBase): Promise<msRestAzure.LROPoller>;
    /**
     * Lists all Network Virtual Appliance Sites in a Network Virtual Appliance resource.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualApplianceSitesListNextResponse>
     */
    listNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.VirtualApplianceSitesListNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.NetworkVirtualApplianceSiteListResult>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.NetworkVirtualApplianceSiteListResult>): void;
}
//# sourceMappingURL=virtualApplianceSites.d.ts.map