import * as msRest from "@azure/ms-rest-js";
import * as msRestAzure from "@azure/ms-rest-azure-js";
import * as Models from "../models";
import { NetworkManagementClientContext } from "../networkManagementClientContext";
/** Class representing a VpnServerConfigurations. */
export declare class VpnServerConfigurations {
    private readonly client;
    /**
     * Create a VpnServerConfigurations.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    constructor(client: NetworkManagementClientContext);
    /**
     * Retrieves the details of a VpnServerConfiguration.
     * @param resourceGroupName The resource group name of the VpnServerConfiguration.
     * @param vpnServerConfigurationName The name of the VpnServerConfiguration being retrieved.
     * @param [options] The optional parameters
     * @returns Promise<Models.VpnServerConfigurationsGetResponse>
     */
    get(resourceGroupName: string, vpnServerConfigurationName: string, options?: msRest.RequestOptionsBase): Promise<Models.VpnServerConfigurationsGetResponse>;
    /**
     * @param resourceGroupName The resource group name of the VpnServerConfiguration.
     * @param vpnServerConfigurationName The name of the VpnServerConfiguration being retrieved.
     * @param callback The callback
     */
    get(resourceGroupName: string, vpnServerConfigurationName: string, callback: msRest.ServiceCallback<Models.VpnServerConfiguration>): void;
    /**
     * @param resourceGroupName The resource group name of the VpnServerConfiguration.
     * @param vpnServerConfigurationName The name of the VpnServerConfiguration being retrieved.
     * @param options The optional parameters
     * @param callback The callback
     */
    get(resourceGroupName: string, vpnServerConfigurationName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.VpnServerConfiguration>): void;
    /**
     * Creates a VpnServerConfiguration resource if it doesn't exist else updates the existing
     * VpnServerConfiguration.
     * @param resourceGroupName The resource group name of the VpnServerConfiguration.
     * @param vpnServerConfigurationName The name of the VpnServerConfiguration being created or
     * updated.
     * @param vpnServerConfigurationParameters Parameters supplied to create or update
     * VpnServerConfiguration.
     * @param [options] The optional parameters
     * @returns Promise<Models.VpnServerConfigurationsCreateOrUpdateResponse>
     */
    createOrUpdate(resourceGroupName: string, vpnServerConfigurationName: string, vpnServerConfigurationParameters: Models.VpnServerConfiguration, options?: msRest.RequestOptionsBase): Promise<Models.VpnServerConfigurationsCreateOrUpdateResponse>;
    /**
     * Updates VpnServerConfiguration tags.
     * @param resourceGroupName The resource group name of the VpnServerConfiguration.
     * @param vpnServerConfigurationName The name of the VpnServerConfiguration being updated.
     * @param vpnServerConfigurationParameters Parameters supplied to update VpnServerConfiguration
     * tags.
     * @param [options] The optional parameters
     * @returns Promise<Models.VpnServerConfigurationsUpdateTagsResponse>
     */
    updateTags(resourceGroupName: string, vpnServerConfigurationName: string, vpnServerConfigurationParameters: Models.TagsObject, options?: msRest.RequestOptionsBase): Promise<Models.VpnServerConfigurationsUpdateTagsResponse>;
    /**
     * @param resourceGroupName The resource group name of the VpnServerConfiguration.
     * @param vpnServerConfigurationName The name of the VpnServerConfiguration being updated.
     * @param vpnServerConfigurationParameters Parameters supplied to update VpnServerConfiguration
     * tags.
     * @param callback The callback
     */
    updateTags(resourceGroupName: string, vpnServerConfigurationName: string, vpnServerConfigurationParameters: Models.TagsObject, callback: msRest.ServiceCallback<Models.VpnServerConfiguration>): void;
    /**
     * @param resourceGroupName The resource group name of the VpnServerConfiguration.
     * @param vpnServerConfigurationName The name of the VpnServerConfiguration being updated.
     * @param vpnServerConfigurationParameters Parameters supplied to update VpnServerConfiguration
     * tags.
     * @param options The optional parameters
     * @param callback The callback
     */
    updateTags(resourceGroupName: string, vpnServerConfigurationName: string, vpnServerConfigurationParameters: Models.TagsObject, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.VpnServerConfiguration>): void;
    /**
     * Deletes a VpnServerConfiguration.
     * @param resourceGroupName The resource group name of the VpnServerConfiguration.
     * @param vpnServerConfigurationName The name of the VpnServerConfiguration being deleted.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    deleteMethod(resourceGroupName: string, vpnServerConfigurationName: string, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * Lists all the vpnServerConfigurations in a resource group.
     * @param resourceGroupName The resource group name of the VpnServerConfiguration.
     * @param [options] The optional parameters
     * @returns Promise<Models.VpnServerConfigurationsListByResourceGroupResponse>
     */
    listByResourceGroup(resourceGroupName: string, options?: msRest.RequestOptionsBase): Promise<Models.VpnServerConfigurationsListByResourceGroupResponse>;
    /**
     * @param resourceGroupName The resource group name of the VpnServerConfiguration.
     * @param callback The callback
     */
    listByResourceGroup(resourceGroupName: string, callback: msRest.ServiceCallback<Models.ListVpnServerConfigurationsResult>): void;
    /**
     * @param resourceGroupName The resource group name of the VpnServerConfiguration.
     * @param options The optional parameters
     * @param callback The callback
     */
    listByResourceGroup(resourceGroupName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.ListVpnServerConfigurationsResult>): void;
    /**
     * Lists all the VpnServerConfigurations in a subscription.
     * @param [options] The optional parameters
     * @returns Promise<Models.VpnServerConfigurationsListResponse>
     */
    list(options?: msRest.RequestOptionsBase): Promise<Models.VpnServerConfigurationsListResponse>;
    /**
     * @param callback The callback
     */
    list(callback: msRest.ServiceCallback<Models.ListVpnServerConfigurationsResult>): void;
    /**
     * @param options The optional parameters
     * @param callback The callback
     */
    list(options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.ListVpnServerConfigurationsResult>): void;
    /**
     * Creates a VpnServerConfiguration resource if it doesn't exist else updates the existing
     * VpnServerConfiguration.
     * @param resourceGroupName The resource group name of the VpnServerConfiguration.
     * @param vpnServerConfigurationName The name of the VpnServerConfiguration being created or
     * updated.
     * @param vpnServerConfigurationParameters Parameters supplied to create or update
     * VpnServerConfiguration.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginCreateOrUpdate(resourceGroupName: string, vpnServerConfigurationName: string, vpnServerConfigurationParameters: Models.VpnServerConfiguration, options?: msRest.RequestOptionsBase): Promise<msRestAzure.LROPoller>;
    /**
     * Deletes a VpnServerConfiguration.
     * @param resourceGroupName The resource group name of the VpnServerConfiguration.
     * @param vpnServerConfigurationName The name of the VpnServerConfiguration being deleted.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginDeleteMethod(resourceGroupName: string, vpnServerConfigurationName: string, options?: msRest.RequestOptionsBase): Promise<msRestAzure.LROPoller>;
    /**
     * Lists all the vpnServerConfigurations in a resource group.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.VpnServerConfigurationsListByResourceGroupNextResponse>
     */
    listByResourceGroupNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.VpnServerConfigurationsListByResourceGroupNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listByResourceGroupNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.ListVpnServerConfigurationsResult>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listByResourceGroupNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.ListVpnServerConfigurationsResult>): void;
    /**
     * Lists all the VpnServerConfigurations in a subscription.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.VpnServerConfigurationsListNextResponse>
     */
    listNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.VpnServerConfigurationsListNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.ListVpnServerConfigurationsResult>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.ListVpnServerConfigurationsResult>): void;
}
//# sourceMappingURL=vpnServerConfigurations.d.ts.map