/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */

import * as msRest from "@azure/ms-rest-js";
import * as Models from "../models";
import * as Mappers from "../models/availableServiceAliasesMappers";
import * as Parameters from "../models/parameters";
import { NetworkManagementClientContext } from "../networkManagementClientContext";

/** Class representing a AvailableServiceAliases. */
export class AvailableServiceAliases {
  private readonly client: NetworkManagementClientContext;

  /**
   * Create a AvailableServiceAliases.
   * @param {NetworkManagementClientContext} client Reference to the service client.
   */
  constructor(client: NetworkManagementClientContext) {
    this.client = client;
  }

  /**
   * Gets all available service aliases for this subscription in this region.
   * @param location The location.
   * @param [options] The optional parameters
   * @returns Promise<Models.AvailableServiceAliasesListResponse>
   */
  list(location: string, options?: msRest.RequestOptionsBase): Promise<Models.AvailableServiceAliasesListResponse>;
  /**
   * @param location The location.
   * @param callback The callback
   */
  list(location: string, callback: msRest.ServiceCallback<Models.AvailableServiceAliasesResult>): void;
  /**
   * @param location The location.
   * @param options The optional parameters
   * @param callback The callback
   */
  list(location: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.AvailableServiceAliasesResult>): void;
  list(location: string, options?: msRest.RequestOptionsBase | msRest.ServiceCallback<Models.AvailableServiceAliasesResult>, callback?: msRest.ServiceCallback<Models.AvailableServiceAliasesResult>): Promise<Models.AvailableServiceAliasesListResponse> {
    return this.client.sendOperationRequest(
      {
        location,
        options
      },
      listOperationSpec,
      callback) as Promise<Models.AvailableServiceAliasesListResponse>;
  }

  /**
   * Gets all available service aliases for this resource group in this region.
   * @param resourceGroupName The name of the resource group.
   * @param location The location.
   * @param [options] The optional parameters
   * @returns Promise<Models.AvailableServiceAliasesListByResourceGroupResponse>
   */
  listByResourceGroup(resourceGroupName: string, location: string, options?: msRest.RequestOptionsBase): Promise<Models.AvailableServiceAliasesListByResourceGroupResponse>;
  /**
   * @param resourceGroupName The name of the resource group.
   * @param location The location.
   * @param callback The callback
   */
  listByResourceGroup(resourceGroupName: string, location: string, callback: msRest.ServiceCallback<Models.AvailableServiceAliasesResult>): void;
  /**
   * @param resourceGroupName The name of the resource group.
   * @param location The location.
   * @param options The optional parameters
   * @param callback The callback
   */
  listByResourceGroup(resourceGroupName: string, location: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.AvailableServiceAliasesResult>): void;
  listByResourceGroup(resourceGroupName: string, location: string, options?: msRest.RequestOptionsBase | msRest.ServiceCallback<Models.AvailableServiceAliasesResult>, callback?: msRest.ServiceCallback<Models.AvailableServiceAliasesResult>): Promise<Models.AvailableServiceAliasesListByResourceGroupResponse> {
    return this.client.sendOperationRequest(
      {
        resourceGroupName,
        location,
        options
      },
      listByResourceGroupOperationSpec,
      callback) as Promise<Models.AvailableServiceAliasesListByResourceGroupResponse>;
  }

  /**
   * Gets all available service aliases for this subscription in this region.
   * @param nextPageLink The NextLink from the previous successful call to List operation.
   * @param [options] The optional parameters
   * @returns Promise<Models.AvailableServiceAliasesListNextResponse>
   */
  listNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.AvailableServiceAliasesListNextResponse>;
  /**
   * @param nextPageLink The NextLink from the previous successful call to List operation.
   * @param callback The callback
   */
  listNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.AvailableServiceAliasesResult>): void;
  /**
   * @param nextPageLink The NextLink from the previous successful call to List operation.
   * @param options The optional parameters
   * @param callback The callback
   */
  listNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.AvailableServiceAliasesResult>): void;
  listNext(nextPageLink: string, options?: msRest.RequestOptionsBase | msRest.ServiceCallback<Models.AvailableServiceAliasesResult>, callback?: msRest.ServiceCallback<Models.AvailableServiceAliasesResult>): Promise<Models.AvailableServiceAliasesListNextResponse> {
    return this.client.sendOperationRequest(
      {
        nextPageLink,
        options
      },
      listNextOperationSpec,
      callback) as Promise<Models.AvailableServiceAliasesListNextResponse>;
  }

  /**
   * Gets all available service aliases for this resource group in this region.
   * @param nextPageLink The NextLink from the previous successful call to List operation.
   * @param [options] The optional parameters
   * @returns Promise<Models.AvailableServiceAliasesListByResourceGroupNextResponse>
   */
  listByResourceGroupNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.AvailableServiceAliasesListByResourceGroupNextResponse>;
  /**
   * @param nextPageLink The NextLink from the previous successful call to List operation.
   * @param callback The callback
   */
  listByResourceGroupNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.AvailableServiceAliasesResult>): void;
  /**
   * @param nextPageLink The NextLink from the previous successful call to List operation.
   * @param options The optional parameters
   * @param callback The callback
   */
  listByResourceGroupNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.AvailableServiceAliasesResult>): void;
  listByResourceGroupNext(nextPageLink: string, options?: msRest.RequestOptionsBase | msRest.ServiceCallback<Models.AvailableServiceAliasesResult>, callback?: msRest.ServiceCallback<Models.AvailableServiceAliasesResult>): Promise<Models.AvailableServiceAliasesListByResourceGroupNextResponse> {
    return this.client.sendOperationRequest(
      {
        nextPageLink,
        options
      },
      listByResourceGroupNextOperationSpec,
      callback) as Promise<Models.AvailableServiceAliasesListByResourceGroupNextResponse>;
  }
}

// Operation Specifications
const serializer = new msRest.Serializer(Mappers);
const listOperationSpec: msRest.OperationSpec = {
  httpMethod: "GET",
  path: "subscriptions/{subscriptionId}/providers/Microsoft.Network/locations/{location}/availableServiceAliases",
  urlParameters: [
    Parameters.location0,
    Parameters.subscriptionId
  ],
  queryParameters: [
    Parameters.apiVersion0
  ],
  headerParameters: [
    Parameters.acceptLanguage
  ],
  responses: {
    200: {
      bodyMapper: Mappers.AvailableServiceAliasesResult
    },
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const listByResourceGroupOperationSpec: msRest.OperationSpec = {
  httpMethod: "GET",
  path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/locations/{location}/availableServiceAliases",
  urlParameters: [
    Parameters.resourceGroupName,
    Parameters.location0,
    Parameters.subscriptionId
  ],
  queryParameters: [
    Parameters.apiVersion0
  ],
  headerParameters: [
    Parameters.acceptLanguage
  ],
  responses: {
    200: {
      bodyMapper: Mappers.AvailableServiceAliasesResult
    },
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const listNextOperationSpec: msRest.OperationSpec = {
  httpMethod: "GET",
  baseUrl: "https://management.azure.com",
  path: "{nextLink}",
  urlParameters: [
    Parameters.nextPageLink
  ],
  queryParameters: [
    Parameters.apiVersion0
  ],
  headerParameters: [
    Parameters.acceptLanguage
  ],
  responses: {
    200: {
      bodyMapper: Mappers.AvailableServiceAliasesResult
    },
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const listByResourceGroupNextOperationSpec: msRest.OperationSpec = {
  httpMethod: "GET",
  baseUrl: "https://management.azure.com",
  path: "{nextLink}",
  urlParameters: [
    Parameters.nextPageLink
  ],
  queryParameters: [
    Parameters.apiVersion0
  ],
  headerParameters: [
    Parameters.acceptLanguage
  ],
  responses: {
    200: {
      bodyMapper: Mappers.AvailableServiceAliasesResult
    },
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};
