/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */

import * as msRest from "@azure/ms-rest-js";
import * as msRestAzure from "@azure/ms-rest-azure-js";
import * as Models from "../models";
import * as Mappers from "../models/ddosCustomPoliciesMappers";
import * as Parameters from "../models/parameters";
import { NetworkManagementClientContext } from "../networkManagementClientContext";

/** Class representing a DdosCustomPolicies. */
export class DdosCustomPolicies {
  private readonly client: NetworkManagementClientContext;

  /**
   * Create a DdosCustomPolicies.
   * @param {NetworkManagementClientContext} client Reference to the service client.
   */
  constructor(client: NetworkManagementClientContext) {
    this.client = client;
  }

  /**
   * Deletes the specified DDoS custom policy.
   * @param resourceGroupName The name of the resource group.
   * @param ddosCustomPolicyName The name of the DDoS custom policy.
   * @param [options] The optional parameters
   * @returns Promise<msRest.RestResponse>
   */
  deleteMethod(resourceGroupName: string, ddosCustomPolicyName: string, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse> {
    return this.beginDeleteMethod(resourceGroupName,ddosCustomPolicyName,options)
      .then(lroPoller => lroPoller.pollUntilFinished());
  }

  /**
   * Gets information about the specified DDoS custom policy.
   * @param resourceGroupName The name of the resource group.
   * @param ddosCustomPolicyName The name of the DDoS custom policy.
   * @param [options] The optional parameters
   * @returns Promise<Models.DdosCustomPoliciesGetResponse>
   */
  get(resourceGroupName: string, ddosCustomPolicyName: string, options?: msRest.RequestOptionsBase): Promise<Models.DdosCustomPoliciesGetResponse>;
  /**
   * @param resourceGroupName The name of the resource group.
   * @param ddosCustomPolicyName The name of the DDoS custom policy.
   * @param callback The callback
   */
  get(resourceGroupName: string, ddosCustomPolicyName: string, callback: msRest.ServiceCallback<Models.DdosCustomPolicy>): void;
  /**
   * @param resourceGroupName The name of the resource group.
   * @param ddosCustomPolicyName The name of the DDoS custom policy.
   * @param options The optional parameters
   * @param callback The callback
   */
  get(resourceGroupName: string, ddosCustomPolicyName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.DdosCustomPolicy>): void;
  get(resourceGroupName: string, ddosCustomPolicyName: string, options?: msRest.RequestOptionsBase | msRest.ServiceCallback<Models.DdosCustomPolicy>, callback?: msRest.ServiceCallback<Models.DdosCustomPolicy>): Promise<Models.DdosCustomPoliciesGetResponse> {
    return this.client.sendOperationRequest(
      {
        resourceGroupName,
        ddosCustomPolicyName,
        options
      },
      getOperationSpec,
      callback) as Promise<Models.DdosCustomPoliciesGetResponse>;
  }

  /**
   * Creates or updates a DDoS custom policy.
   * @param resourceGroupName The name of the resource group.
   * @param ddosCustomPolicyName The name of the DDoS custom policy.
   * @param parameters Parameters supplied to the create or update operation.
   * @param [options] The optional parameters
   * @returns Promise<Models.DdosCustomPoliciesCreateOrUpdateResponse>
   */
  createOrUpdate(resourceGroupName: string, ddosCustomPolicyName: string, parameters: Models.DdosCustomPolicy, options?: msRest.RequestOptionsBase): Promise<Models.DdosCustomPoliciesCreateOrUpdateResponse> {
    return this.beginCreateOrUpdate(resourceGroupName,ddosCustomPolicyName,parameters,options)
      .then(lroPoller => lroPoller.pollUntilFinished()) as Promise<Models.DdosCustomPoliciesCreateOrUpdateResponse>;
  }

  /**
   * Update a DDoS custom policy tags.
   * @param resourceGroupName The name of the resource group.
   * @param ddosCustomPolicyName The name of the DDoS custom policy.
   * @param parameters Parameters supplied to update DDoS custom policy resource tags.
   * @param [options] The optional parameters
   * @returns Promise<Models.DdosCustomPoliciesUpdateTagsResponse>
   */
  updateTags(resourceGroupName: string, ddosCustomPolicyName: string, parameters: Models.TagsObject, options?: msRest.RequestOptionsBase): Promise<Models.DdosCustomPoliciesUpdateTagsResponse>;
  /**
   * @param resourceGroupName The name of the resource group.
   * @param ddosCustomPolicyName The name of the DDoS custom policy.
   * @param parameters Parameters supplied to update DDoS custom policy resource tags.
   * @param callback The callback
   */
  updateTags(resourceGroupName: string, ddosCustomPolicyName: string, parameters: Models.TagsObject, callback: msRest.ServiceCallback<Models.DdosCustomPolicy>): void;
  /**
   * @param resourceGroupName The name of the resource group.
   * @param ddosCustomPolicyName The name of the DDoS custom policy.
   * @param parameters Parameters supplied to update DDoS custom policy resource tags.
   * @param options The optional parameters
   * @param callback The callback
   */
  updateTags(resourceGroupName: string, ddosCustomPolicyName: string, parameters: Models.TagsObject, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.DdosCustomPolicy>): void;
  updateTags(resourceGroupName: string, ddosCustomPolicyName: string, parameters: Models.TagsObject, options?: msRest.RequestOptionsBase | msRest.ServiceCallback<Models.DdosCustomPolicy>, callback?: msRest.ServiceCallback<Models.DdosCustomPolicy>): Promise<Models.DdosCustomPoliciesUpdateTagsResponse> {
    return this.client.sendOperationRequest(
      {
        resourceGroupName,
        ddosCustomPolicyName,
        parameters,
        options
      },
      updateTagsOperationSpec,
      callback) as Promise<Models.DdosCustomPoliciesUpdateTagsResponse>;
  }

  /**
   * Deletes the specified DDoS custom policy.
   * @param resourceGroupName The name of the resource group.
   * @param ddosCustomPolicyName The name of the DDoS custom policy.
   * @param [options] The optional parameters
   * @returns Promise<msRestAzure.LROPoller>
   */
  beginDeleteMethod(resourceGroupName: string, ddosCustomPolicyName: string, options?: msRest.RequestOptionsBase): Promise<msRestAzure.LROPoller> {
    return this.client.sendLRORequest(
      {
        resourceGroupName,
        ddosCustomPolicyName,
        options
      },
      beginDeleteMethodOperationSpec,
      options);
  }

  /**
   * Creates or updates a DDoS custom policy.
   * @param resourceGroupName The name of the resource group.
   * @param ddosCustomPolicyName The name of the DDoS custom policy.
   * @param parameters Parameters supplied to the create or update operation.
   * @param [options] The optional parameters
   * @returns Promise<msRestAzure.LROPoller>
   */
  beginCreateOrUpdate(resourceGroupName: string, ddosCustomPolicyName: string, parameters: Models.DdosCustomPolicy, options?: msRest.RequestOptionsBase): Promise<msRestAzure.LROPoller> {
    return this.client.sendLRORequest(
      {
        resourceGroupName,
        ddosCustomPolicyName,
        parameters,
        options
      },
      beginCreateOrUpdateOperationSpec,
      options);
  }
}

// Operation Specifications
const serializer = new msRest.Serializer(Mappers);
const getOperationSpec: msRest.OperationSpec = {
  httpMethod: "GET",
  path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/ddosCustomPolicies/{ddosCustomPolicyName}",
  urlParameters: [
    Parameters.resourceGroupName,
    Parameters.ddosCustomPolicyName,
    Parameters.subscriptionId
  ],
  queryParameters: [
    Parameters.apiVersion0
  ],
  headerParameters: [
    Parameters.acceptLanguage
  ],
  responses: {
    200: {
      bodyMapper: Mappers.DdosCustomPolicy
    },
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const updateTagsOperationSpec: msRest.OperationSpec = {
  httpMethod: "PATCH",
  path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/ddosCustomPolicies/{ddosCustomPolicyName}",
  urlParameters: [
    Parameters.resourceGroupName,
    Parameters.ddosCustomPolicyName,
    Parameters.subscriptionId
  ],
  queryParameters: [
    Parameters.apiVersion0
  ],
  headerParameters: [
    Parameters.acceptLanguage
  ],
  requestBody: {
    parameterPath: "parameters",
    mapper: {
      ...Mappers.TagsObject,
      required: true
    }
  },
  responses: {
    200: {
      bodyMapper: Mappers.DdosCustomPolicy
    },
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const beginDeleteMethodOperationSpec: msRest.OperationSpec = {
  httpMethod: "DELETE",
  path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/ddosCustomPolicies/{ddosCustomPolicyName}",
  urlParameters: [
    Parameters.resourceGroupName,
    Parameters.ddosCustomPolicyName,
    Parameters.subscriptionId
  ],
  queryParameters: [
    Parameters.apiVersion0
  ],
  headerParameters: [
    Parameters.acceptLanguage
  ],
  responses: {
    200: {},
    202: {},
    204: {},
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const beginCreateOrUpdateOperationSpec: msRest.OperationSpec = {
  httpMethod: "PUT",
  path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/ddosCustomPolicies/{ddosCustomPolicyName}",
  urlParameters: [
    Parameters.resourceGroupName,
    Parameters.ddosCustomPolicyName,
    Parameters.subscriptionId
  ],
  queryParameters: [
    Parameters.apiVersion0
  ],
  headerParameters: [
    Parameters.acceptLanguage
  ],
  requestBody: {
    parameterPath: "parameters",
    mapper: {
      ...Mappers.DdosCustomPolicy,
      required: true
    }
  },
  responses: {
    200: {
      bodyMapper: Mappers.DdosCustomPolicy
    },
    201: {
      bodyMapper: Mappers.DdosCustomPolicy
    },
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};
