/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */

import * as msRest from "@azure/ms-rest-js";
import * as msRestAzure from "@azure/ms-rest-azure-js";
import * as Models from "../models";
import * as Mappers from "../models/resourcesMappers";
import * as Parameters from "../models/parameters";
import { ResourceManagementClientContext } from "../resourceManagementClientContext";

/** Class representing a Resources. */
export class Resources {
  private readonly client: ResourceManagementClientContext;

  /**
   * Create a Resources.
   * @param {ResourceManagementClientContext} client Reference to the service client.
   */
  constructor(client: ResourceManagementClientContext) {
    this.client = client;
  }

  /**
   * Get all the resources for a resource group.
   * @param resourceGroupName The resource group with the resources to get.
   * @param [options] The optional parameters
   * @returns Promise<Models.ResourcesListByResourceGroupResponse>
   */
  listByResourceGroup(
    resourceGroupName: string,
    options?: Models.ResourcesListByResourceGroupOptionalParams
  ): Promise<Models.ResourcesListByResourceGroupResponse>;
  /**
   * @param resourceGroupName The resource group with the resources to get.
   * @param callback The callback
   */
  listByResourceGroup(
    resourceGroupName: string,
    callback: msRest.ServiceCallback<Models.ResourceListResult>
  ): void;
  /**
   * @param resourceGroupName The resource group with the resources to get.
   * @param options The optional parameters
   * @param callback The callback
   */
  listByResourceGroup(
    resourceGroupName: string,
    options: Models.ResourcesListByResourceGroupOptionalParams,
    callback: msRest.ServiceCallback<Models.ResourceListResult>
  ): void;
  listByResourceGroup(
    resourceGroupName: string,
    options?:
      | Models.ResourcesListByResourceGroupOptionalParams
      | msRest.ServiceCallback<Models.ResourceListResult>,
    callback?: msRest.ServiceCallback<Models.ResourceListResult>
  ): Promise<Models.ResourcesListByResourceGroupResponse> {
    return this.client.sendOperationRequest(
      {
        resourceGroupName,
        options
      },
      listByResourceGroupOperationSpec,
      callback
    ) as Promise<Models.ResourcesListByResourceGroupResponse>;
  }

  /**
   * The resources to move must be in the same source resource group. The target resource group may
   * be in a different subscription. When moving resources, both the source group and the target
   * group are locked for the duration of the operation. Write and delete operations are blocked on
   * the groups until the move completes.
   * @summary Moves resources from one resource group to another resource group.
   * @param sourceResourceGroupName The name of the resource group containing the resources to move.
   * @param parameters Parameters for moving resources.
   * @param [options] The optional parameters
   * @returns Promise<msRest.RestResponse>
   */
  moveResources(
    sourceResourceGroupName: string,
    parameters: Models.ResourcesMoveInfo,
    options?: msRest.RequestOptionsBase
  ): Promise<msRest.RestResponse> {
    return this.beginMoveResources(sourceResourceGroupName, parameters, options).then((lroPoller) =>
      lroPoller.pollUntilFinished()
    );
  }

  /**
   * This operation checks whether the specified resources can be moved to the target. The resources
   * to move must be in the same source resource group. The target resource group may be in a
   * different subscription. If validation succeeds, it returns HTTP response code 204 (no content).
   * If validation fails, it returns HTTP response code 409 (Conflict) with an error message.
   * Retrieve the URL in the Location header value to check the result of the long-running operation.
   * @summary Validates whether resources can be moved from one resource group to another resource
   * group.
   * @param sourceResourceGroupName The name of the resource group containing the resources to
   * validate for move.
   * @param parameters Parameters for moving resources.
   * @param [options] The optional parameters
   * @returns Promise<msRest.RestResponse>
   */
  validateMoveResources(
    sourceResourceGroupName: string,
    parameters: Models.ResourcesMoveInfo,
    options?: msRest.RequestOptionsBase
  ): Promise<msRest.RestResponse> {
    return this.beginValidateMoveResources(
      sourceResourceGroupName,
      parameters,
      options
    ).then((lroPoller) => lroPoller.pollUntilFinished());
  }

  /**
   * Get all the resources in a subscription.
   * @param [options] The optional parameters
   * @returns Promise<Models.ResourcesListResponse>
   */
  list(options?: Models.ResourcesListOptionalParams): Promise<Models.ResourcesListResponse>;
  /**
   * @param callback The callback
   */
  list(callback: msRest.ServiceCallback<Models.ResourceListResult>): void;
  /**
   * @param options The optional parameters
   * @param callback The callback
   */
  list(
    options: Models.ResourcesListOptionalParams,
    callback: msRest.ServiceCallback<Models.ResourceListResult>
  ): void;
  list(
    options?:
      | Models.ResourcesListOptionalParams
      | msRest.ServiceCallback<Models.ResourceListResult>,
    callback?: msRest.ServiceCallback<Models.ResourceListResult>
  ): Promise<Models.ResourcesListResponse> {
    return this.client.sendOperationRequest(
      {
        options
      },
      listOperationSpec,
      callback
    ) as Promise<Models.ResourcesListResponse>;
  }

  /**
   * Checks whether a resource exists.
   * @param resourceGroupName The name of the resource group containing the resource to check. The
   * name is case insensitive.
   * @param resourceProviderNamespace The resource provider of the resource to check.
   * @param parentResourcePath The parent resource identity.
   * @param resourceType The resource type.
   * @param resourceName The name of the resource to check whether it exists.
   * @param apiVersion The API version to use for the operation.
   * @param [options] The optional parameters
   * @returns Promise<Models.ResourcesCheckExistenceResponse>
   */
  checkExistence(
    resourceGroupName: string,
    resourceProviderNamespace: string,
    parentResourcePath: string,
    resourceType: string,
    resourceName: string,
    apiVersion: string,
    options?: msRest.RequestOptionsBase
  ): Promise<Models.ResourcesCheckExistenceResponse>;
  /**
   * @param resourceGroupName The name of the resource group containing the resource to check. The
   * name is case insensitive.
   * @param resourceProviderNamespace The resource provider of the resource to check.
   * @param parentResourcePath The parent resource identity.
   * @param resourceType The resource type.
   * @param resourceName The name of the resource to check whether it exists.
   * @param apiVersion The API version to use for the operation.
   * @param callback The callback
   */
  checkExistence(
    resourceGroupName: string,
    resourceProviderNamespace: string,
    parentResourcePath: string,
    resourceType: string,
    resourceName: string,
    apiVersion: string,
    callback: msRest.ServiceCallback<boolean>
  ): void;
  /**
   * @param resourceGroupName The name of the resource group containing the resource to check. The
   * name is case insensitive.
   * @param resourceProviderNamespace The resource provider of the resource to check.
   * @param parentResourcePath The parent resource identity.
   * @param resourceType The resource type.
   * @param resourceName The name of the resource to check whether it exists.
   * @param apiVersion The API version to use for the operation.
   * @param options The optional parameters
   * @param callback The callback
   */
  checkExistence(
    resourceGroupName: string,
    resourceProviderNamespace: string,
    parentResourcePath: string,
    resourceType: string,
    resourceName: string,
    apiVersion: string,
    options: msRest.RequestOptionsBase,
    callback: msRest.ServiceCallback<boolean>
  ): void;
  checkExistence(
    resourceGroupName: string,
    resourceProviderNamespace: string,
    parentResourcePath: string,
    resourceType: string,
    resourceName: string,
    apiVersion: string,
    options?: msRest.RequestOptionsBase | msRest.ServiceCallback<boolean>,
    callback?: msRest.ServiceCallback<boolean>
  ): Promise<Models.ResourcesCheckExistenceResponse> {
    return this.client.sendOperationRequest(
      {
        resourceGroupName,
        resourceProviderNamespace,
        parentResourcePath,
        resourceType,
        resourceName,
        apiVersion,
        options
      },
      checkExistenceOperationSpec,
      callback
    ) as Promise<Models.ResourcesCheckExistenceResponse>;
  }

  /**
   * Deletes a resource.
   * @param resourceGroupName The name of the resource group that contains the resource to delete.
   * The name is case insensitive.
   * @param resourceProviderNamespace The namespace of the resource provider.
   * @param parentResourcePath The parent resource identity.
   * @param resourceType The resource type.
   * @param resourceName The name of the resource to delete.
   * @param apiVersion The API version to use for the operation.
   * @param [options] The optional parameters
   * @returns Promise<msRest.RestResponse>
   */
  deleteMethod(
    resourceGroupName: string,
    resourceProviderNamespace: string,
    parentResourcePath: string,
    resourceType: string,
    resourceName: string,
    apiVersion: string,
    options?: msRest.RequestOptionsBase
  ): Promise<msRest.RestResponse> {
    return this.beginDeleteMethod(
      resourceGroupName,
      resourceProviderNamespace,
      parentResourcePath,
      resourceType,
      resourceName,
      apiVersion,
      options
    ).then((lroPoller) => lroPoller.pollUntilFinished());
  }

  /**
   * Creates a resource.
   * @param resourceGroupName The name of the resource group for the resource. The name is case
   * insensitive.
   * @param resourceProviderNamespace The namespace of the resource provider.
   * @param parentResourcePath The parent resource identity.
   * @param resourceType The resource type of the resource to create.
   * @param resourceName The name of the resource to create.
   * @param apiVersion The API version to use for the operation.
   * @param parameters Parameters for creating or updating the resource.
   * @param [options] The optional parameters
   * @returns Promise<Models.ResourcesCreateOrUpdateResponse>
   */
  createOrUpdate(
    resourceGroupName: string,
    resourceProviderNamespace: string,
    parentResourcePath: string,
    resourceType: string,
    resourceName: string,
    apiVersion: string,
    parameters: Models.GenericResource,
    options?: msRest.RequestOptionsBase
  ): Promise<Models.ResourcesCreateOrUpdateResponse> {
    return this.beginCreateOrUpdate(
      resourceGroupName,
      resourceProviderNamespace,
      parentResourcePath,
      resourceType,
      resourceName,
      apiVersion,
      parameters,
      options
    ).then((lroPoller) => lroPoller.pollUntilFinished()) as Promise<
      Models.ResourcesCreateOrUpdateResponse
    >;
  }

  /**
   * Updates a resource.
   * @param resourceGroupName The name of the resource group for the resource. The name is case
   * insensitive.
   * @param resourceProviderNamespace The namespace of the resource provider.
   * @param parentResourcePath The parent resource identity.
   * @param resourceType The resource type of the resource to update.
   * @param resourceName The name of the resource to update.
   * @param apiVersion The API version to use for the operation.
   * @param parameters Parameters for updating the resource.
   * @param [options] The optional parameters
   * @returns Promise<Models.ResourcesUpdateResponse>
   */
  update(
    resourceGroupName: string,
    resourceProviderNamespace: string,
    parentResourcePath: string,
    resourceType: string,
    resourceName: string,
    apiVersion: string,
    parameters: Models.GenericResource,
    options?: msRest.RequestOptionsBase
  ): Promise<Models.ResourcesUpdateResponse> {
    return this.beginUpdate(
      resourceGroupName,
      resourceProviderNamespace,
      parentResourcePath,
      resourceType,
      resourceName,
      apiVersion,
      parameters,
      options
    ).then((lroPoller) => lroPoller.pollUntilFinished()) as Promise<Models.ResourcesUpdateResponse>;
  }

  /**
   * Gets a resource.
   * @param resourceGroupName The name of the resource group containing the resource to get. The name
   * is case insensitive.
   * @param resourceProviderNamespace The namespace of the resource provider.
   * @param parentResourcePath The parent resource identity.
   * @param resourceType The resource type of the resource.
   * @param resourceName The name of the resource to get.
   * @param apiVersion The API version to use for the operation.
   * @param [options] The optional parameters
   * @returns Promise<Models.ResourcesGetResponse>
   */
  get(
    resourceGroupName: string,
    resourceProviderNamespace: string,
    parentResourcePath: string,
    resourceType: string,
    resourceName: string,
    apiVersion: string,
    options?: msRest.RequestOptionsBase
  ): Promise<Models.ResourcesGetResponse>;
  /**
   * @param resourceGroupName The name of the resource group containing the resource to get. The name
   * is case insensitive.
   * @param resourceProviderNamespace The namespace of the resource provider.
   * @param parentResourcePath The parent resource identity.
   * @param resourceType The resource type of the resource.
   * @param resourceName The name of the resource to get.
   * @param apiVersion The API version to use for the operation.
   * @param callback The callback
   */
  get(
    resourceGroupName: string,
    resourceProviderNamespace: string,
    parentResourcePath: string,
    resourceType: string,
    resourceName: string,
    apiVersion: string,
    callback: msRest.ServiceCallback<Models.GenericResource>
  ): void;
  /**
   * @param resourceGroupName The name of the resource group containing the resource to get. The name
   * is case insensitive.
   * @param resourceProviderNamespace The namespace of the resource provider.
   * @param parentResourcePath The parent resource identity.
   * @param resourceType The resource type of the resource.
   * @param resourceName The name of the resource to get.
   * @param apiVersion The API version to use for the operation.
   * @param options The optional parameters
   * @param callback The callback
   */
  get(
    resourceGroupName: string,
    resourceProviderNamespace: string,
    parentResourcePath: string,
    resourceType: string,
    resourceName: string,
    apiVersion: string,
    options: msRest.RequestOptionsBase,
    callback: msRest.ServiceCallback<Models.GenericResource>
  ): void;
  get(
    resourceGroupName: string,
    resourceProviderNamespace: string,
    parentResourcePath: string,
    resourceType: string,
    resourceName: string,
    apiVersion: string,
    options?: msRest.RequestOptionsBase | msRest.ServiceCallback<Models.GenericResource>,
    callback?: msRest.ServiceCallback<Models.GenericResource>
  ): Promise<Models.ResourcesGetResponse> {
    return this.client.sendOperationRequest(
      {
        resourceGroupName,
        resourceProviderNamespace,
        parentResourcePath,
        resourceType,
        resourceName,
        apiVersion,
        options
      },
      getOperationSpec,
      callback
    ) as Promise<Models.ResourcesGetResponse>;
  }

  /**
   * Checks by ID whether a resource exists.
   * @param resourceId The fully qualified ID of the resource, including the resource name and
   * resource type. Use the format,
   * /subscriptions/{guid}/resourceGroups/{resource-group-name}/{resource-provider-namespace}/{resource-type}/{resource-name}
   * @param apiVersion The API version to use for the operation.
   * @param [options] The optional parameters
   * @returns Promise<Models.ResourcesCheckExistenceByIdResponse>
   */
  checkExistenceById(
    resourceId: string,
    apiVersion: string,
    options?: msRest.RequestOptionsBase
  ): Promise<Models.ResourcesCheckExistenceByIdResponse>;
  /**
   * @param resourceId The fully qualified ID of the resource, including the resource name and
   * resource type. Use the format,
   * /subscriptions/{guid}/resourceGroups/{resource-group-name}/{resource-provider-namespace}/{resource-type}/{resource-name}
   * @param apiVersion The API version to use for the operation.
   * @param callback The callback
   */
  checkExistenceById(
    resourceId: string,
    apiVersion: string,
    callback: msRest.ServiceCallback<boolean>
  ): void;
  /**
   * @param resourceId The fully qualified ID of the resource, including the resource name and
   * resource type. Use the format,
   * /subscriptions/{guid}/resourceGroups/{resource-group-name}/{resource-provider-namespace}/{resource-type}/{resource-name}
   * @param apiVersion The API version to use for the operation.
   * @param options The optional parameters
   * @param callback The callback
   */
  checkExistenceById(
    resourceId: string,
    apiVersion: string,
    options: msRest.RequestOptionsBase,
    callback: msRest.ServiceCallback<boolean>
  ): void;
  checkExistenceById(
    resourceId: string,
    apiVersion: string,
    options?: msRest.RequestOptionsBase | msRest.ServiceCallback<boolean>,
    callback?: msRest.ServiceCallback<boolean>
  ): Promise<Models.ResourcesCheckExistenceByIdResponse> {
    return this.client.sendOperationRequest(
      {
        resourceId,
        apiVersion,
        options
      },
      checkExistenceByIdOperationSpec,
      callback
    ) as Promise<Models.ResourcesCheckExistenceByIdResponse>;
  }

  /**
   * Deletes a resource by ID.
   * @param resourceId The fully qualified ID of the resource, including the resource name and
   * resource type. Use the format,
   * /subscriptions/{guid}/resourceGroups/{resource-group-name}/{resource-provider-namespace}/{resource-type}/{resource-name}
   * @param apiVersion The API version to use for the operation.
   * @param [options] The optional parameters
   * @returns Promise<msRest.RestResponse>
   */
  deleteById(
    resourceId: string,
    apiVersion: string,
    options?: msRest.RequestOptionsBase
  ): Promise<msRest.RestResponse> {
    return this.beginDeleteById(resourceId, apiVersion, options).then((lroPoller) =>
      lroPoller.pollUntilFinished()
    );
  }

  /**
   * Create a resource by ID.
   * @param resourceId The fully qualified ID of the resource, including the resource name and
   * resource type. Use the format,
   * /subscriptions/{guid}/resourceGroups/{resource-group-name}/{resource-provider-namespace}/{resource-type}/{resource-name}
   * @param apiVersion The API version to use for the operation.
   * @param parameters Create or update resource parameters.
   * @param [options] The optional parameters
   * @returns Promise<Models.ResourcesCreateOrUpdateByIdResponse>
   */
  createOrUpdateById(
    resourceId: string,
    apiVersion: string,
    parameters: Models.GenericResource,
    options?: msRest.RequestOptionsBase
  ): Promise<Models.ResourcesCreateOrUpdateByIdResponse> {
    return this.beginCreateOrUpdateById(
      resourceId,
      apiVersion,
      parameters,
      options
    ).then((lroPoller) => lroPoller.pollUntilFinished()) as Promise<
      Models.ResourcesCreateOrUpdateByIdResponse
    >;
  }

  /**
   * Updates a resource by ID.
   * @param resourceId The fully qualified ID of the resource, including the resource name and
   * resource type. Use the format,
   * /subscriptions/{guid}/resourceGroups/{resource-group-name}/{resource-provider-namespace}/{resource-type}/{resource-name}
   * @param apiVersion The API version to use for the operation.
   * @param parameters Update resource parameters.
   * @param [options] The optional parameters
   * @returns Promise<Models.ResourcesUpdateByIdResponse>
   */
  updateById(
    resourceId: string,
    apiVersion: string,
    parameters: Models.GenericResource,
    options?: msRest.RequestOptionsBase
  ): Promise<Models.ResourcesUpdateByIdResponse> {
    return this.beginUpdateById(resourceId, apiVersion, parameters, options).then((lroPoller) =>
      lroPoller.pollUntilFinished()
    ) as Promise<Models.ResourcesUpdateByIdResponse>;
  }

  /**
   * Gets a resource by ID.
   * @param resourceId The fully qualified ID of the resource, including the resource name and
   * resource type. Use the format,
   * /subscriptions/{guid}/resourceGroups/{resource-group-name}/{resource-provider-namespace}/{resource-type}/{resource-name}
   * @param apiVersion The API version to use for the operation.
   * @param [options] The optional parameters
   * @returns Promise<Models.ResourcesGetByIdResponse>
   */
  getById(
    resourceId: string,
    apiVersion: string,
    options?: msRest.RequestOptionsBase
  ): Promise<Models.ResourcesGetByIdResponse>;
  /**
   * @param resourceId The fully qualified ID of the resource, including the resource name and
   * resource type. Use the format,
   * /subscriptions/{guid}/resourceGroups/{resource-group-name}/{resource-provider-namespace}/{resource-type}/{resource-name}
   * @param apiVersion The API version to use for the operation.
   * @param callback The callback
   */
  getById(
    resourceId: string,
    apiVersion: string,
    callback: msRest.ServiceCallback<Models.GenericResource>
  ): void;
  /**
   * @param resourceId The fully qualified ID of the resource, including the resource name and
   * resource type. Use the format,
   * /subscriptions/{guid}/resourceGroups/{resource-group-name}/{resource-provider-namespace}/{resource-type}/{resource-name}
   * @param apiVersion The API version to use for the operation.
   * @param options The optional parameters
   * @param callback The callback
   */
  getById(
    resourceId: string,
    apiVersion: string,
    options: msRest.RequestOptionsBase,
    callback: msRest.ServiceCallback<Models.GenericResource>
  ): void;
  getById(
    resourceId: string,
    apiVersion: string,
    options?: msRest.RequestOptionsBase | msRest.ServiceCallback<Models.GenericResource>,
    callback?: msRest.ServiceCallback<Models.GenericResource>
  ): Promise<Models.ResourcesGetByIdResponse> {
    return this.client.sendOperationRequest(
      {
        resourceId,
        apiVersion,
        options
      },
      getByIdOperationSpec,
      callback
    ) as Promise<Models.ResourcesGetByIdResponse>;
  }

  /**
   * The resources to move must be in the same source resource group. The target resource group may
   * be in a different subscription. When moving resources, both the source group and the target
   * group are locked for the duration of the operation. Write and delete operations are blocked on
   * the groups until the move completes.
   * @summary Moves resources from one resource group to another resource group.
   * @param sourceResourceGroupName The name of the resource group containing the resources to move.
   * @param parameters Parameters for moving resources.
   * @param [options] The optional parameters
   * @returns Promise<msRestAzure.LROPoller>
   */
  beginMoveResources(
    sourceResourceGroupName: string,
    parameters: Models.ResourcesMoveInfo,
    options?: msRest.RequestOptionsBase
  ): Promise<msRestAzure.LROPoller> {
    return this.client.sendLRORequest(
      {
        sourceResourceGroupName,
        parameters,
        options
      },
      beginMoveResourcesOperationSpec,
      options
    );
  }

  /**
   * This operation checks whether the specified resources can be moved to the target. The resources
   * to move must be in the same source resource group. The target resource group may be in a
   * different subscription. If validation succeeds, it returns HTTP response code 204 (no content).
   * If validation fails, it returns HTTP response code 409 (Conflict) with an error message.
   * Retrieve the URL in the Location header value to check the result of the long-running operation.
   * @summary Validates whether resources can be moved from one resource group to another resource
   * group.
   * @param sourceResourceGroupName The name of the resource group containing the resources to
   * validate for move.
   * @param parameters Parameters for moving resources.
   * @param [options] The optional parameters
   * @returns Promise<msRestAzure.LROPoller>
   */
  beginValidateMoveResources(
    sourceResourceGroupName: string,
    parameters: Models.ResourcesMoveInfo,
    options?: msRest.RequestOptionsBase
  ): Promise<msRestAzure.LROPoller> {
    return this.client.sendLRORequest(
      {
        sourceResourceGroupName,
        parameters,
        options
      },
      beginValidateMoveResourcesOperationSpec,
      options
    );
  }

  /**
   * Deletes a resource.
   * @param resourceGroupName The name of the resource group that contains the resource to delete.
   * The name is case insensitive.
   * @param resourceProviderNamespace The namespace of the resource provider.
   * @param parentResourcePath The parent resource identity.
   * @param resourceType The resource type.
   * @param resourceName The name of the resource to delete.
   * @param apiVersion The API version to use for the operation.
   * @param [options] The optional parameters
   * @returns Promise<msRestAzure.LROPoller>
   */
  beginDeleteMethod(
    resourceGroupName: string,
    resourceProviderNamespace: string,
    parentResourcePath: string,
    resourceType: string,
    resourceName: string,
    apiVersion: string,
    options?: msRest.RequestOptionsBase
  ): Promise<msRestAzure.LROPoller> {
    return this.client.sendLRORequest(
      {
        resourceGroupName,
        resourceProviderNamespace,
        parentResourcePath,
        resourceType,
        resourceName,
        apiVersion,
        options
      },
      beginDeleteMethodOperationSpec,
      options
    );
  }

  /**
   * Creates a resource.
   * @param resourceGroupName The name of the resource group for the resource. The name is case
   * insensitive.
   * @param resourceProviderNamespace The namespace of the resource provider.
   * @param parentResourcePath The parent resource identity.
   * @param resourceType The resource type of the resource to create.
   * @param resourceName The name of the resource to create.
   * @param apiVersion The API version to use for the operation.
   * @param parameters Parameters for creating or updating the resource.
   * @param [options] The optional parameters
   * @returns Promise<msRestAzure.LROPoller>
   */
  beginCreateOrUpdate(
    resourceGroupName: string,
    resourceProviderNamespace: string,
    parentResourcePath: string,
    resourceType: string,
    resourceName: string,
    apiVersion: string,
    parameters: Models.GenericResource,
    options?: msRest.RequestOptionsBase
  ): Promise<msRestAzure.LROPoller> {
    return this.client.sendLRORequest(
      {
        resourceGroupName,
        resourceProviderNamespace,
        parentResourcePath,
        resourceType,
        resourceName,
        apiVersion,
        parameters,
        options
      },
      beginCreateOrUpdateOperationSpec,
      options
    );
  }

  /**
   * Updates a resource.
   * @param resourceGroupName The name of the resource group for the resource. The name is case
   * insensitive.
   * @param resourceProviderNamespace The namespace of the resource provider.
   * @param parentResourcePath The parent resource identity.
   * @param resourceType The resource type of the resource to update.
   * @param resourceName The name of the resource to update.
   * @param apiVersion The API version to use for the operation.
   * @param parameters Parameters for updating the resource.
   * @param [options] The optional parameters
   * @returns Promise<msRestAzure.LROPoller>
   */
  beginUpdate(
    resourceGroupName: string,
    resourceProviderNamespace: string,
    parentResourcePath: string,
    resourceType: string,
    resourceName: string,
    apiVersion: string,
    parameters: Models.GenericResource,
    options?: msRest.RequestOptionsBase
  ): Promise<msRestAzure.LROPoller> {
    return this.client.sendLRORequest(
      {
        resourceGroupName,
        resourceProviderNamespace,
        parentResourcePath,
        resourceType,
        resourceName,
        apiVersion,
        parameters,
        options
      },
      beginUpdateOperationSpec,
      options
    );
  }

  /**
   * Deletes a resource by ID.
   * @param resourceId The fully qualified ID of the resource, including the resource name and
   * resource type. Use the format,
   * /subscriptions/{guid}/resourceGroups/{resource-group-name}/{resource-provider-namespace}/{resource-type}/{resource-name}
   * @param apiVersion The API version to use for the operation.
   * @param [options] The optional parameters
   * @returns Promise<msRestAzure.LROPoller>
   */
  beginDeleteById(
    resourceId: string,
    apiVersion: string,
    options?: msRest.RequestOptionsBase
  ): Promise<msRestAzure.LROPoller> {
    return this.client.sendLRORequest(
      {
        resourceId,
        apiVersion,
        options
      },
      beginDeleteByIdOperationSpec,
      options
    );
  }

  /**
   * Create a resource by ID.
   * @param resourceId The fully qualified ID of the resource, including the resource name and
   * resource type. Use the format,
   * /subscriptions/{guid}/resourceGroups/{resource-group-name}/{resource-provider-namespace}/{resource-type}/{resource-name}
   * @param apiVersion The API version to use for the operation.
   * @param parameters Create or update resource parameters.
   * @param [options] The optional parameters
   * @returns Promise<msRestAzure.LROPoller>
   */
  beginCreateOrUpdateById(
    resourceId: string,
    apiVersion: string,
    parameters: Models.GenericResource,
    options?: msRest.RequestOptionsBase
  ): Promise<msRestAzure.LROPoller> {
    return this.client.sendLRORequest(
      {
        resourceId,
        apiVersion,
        parameters,
        options
      },
      beginCreateOrUpdateByIdOperationSpec,
      options
    );
  }

  /**
   * Updates a resource by ID.
   * @param resourceId The fully qualified ID of the resource, including the resource name and
   * resource type. Use the format,
   * /subscriptions/{guid}/resourceGroups/{resource-group-name}/{resource-provider-namespace}/{resource-type}/{resource-name}
   * @param apiVersion The API version to use for the operation.
   * @param parameters Update resource parameters.
   * @param [options] The optional parameters
   * @returns Promise<msRestAzure.LROPoller>
   */
  beginUpdateById(
    resourceId: string,
    apiVersion: string,
    parameters: Models.GenericResource,
    options?: msRest.RequestOptionsBase
  ): Promise<msRestAzure.LROPoller> {
    return this.client.sendLRORequest(
      {
        resourceId,
        apiVersion,
        parameters,
        options
      },
      beginUpdateByIdOperationSpec,
      options
    );
  }

  /**
   * Get all the resources for a resource group.
   * @param nextPageLink The NextLink from the previous successful call to List operation.
   * @param [options] The optional parameters
   * @returns Promise<Models.ResourcesListByResourceGroupNextResponse>
   */
  listByResourceGroupNext(
    nextPageLink: string,
    options?: Models.ResourcesListByResourceGroupNextOptionalParams
  ): Promise<Models.ResourcesListByResourceGroupNextResponse>;
  /**
   * @param nextPageLink The NextLink from the previous successful call to List operation.
   * @param callback The callback
   */
  listByResourceGroupNext(
    nextPageLink: string,
    callback: msRest.ServiceCallback<Models.ResourceListResult>
  ): void;
  /**
   * @param nextPageLink The NextLink from the previous successful call to List operation.
   * @param options The optional parameters
   * @param callback The callback
   */
  listByResourceGroupNext(
    nextPageLink: string,
    options: Models.ResourcesListByResourceGroupNextOptionalParams,
    callback: msRest.ServiceCallback<Models.ResourceListResult>
  ): void;
  listByResourceGroupNext(
    nextPageLink: string,
    options?:
      | Models.ResourcesListByResourceGroupNextOptionalParams
      | msRest.ServiceCallback<Models.ResourceListResult>,
    callback?: msRest.ServiceCallback<Models.ResourceListResult>
  ): Promise<Models.ResourcesListByResourceGroupNextResponse> {
    return this.client.sendOperationRequest(
      {
        nextPageLink,
        options
      },
      listByResourceGroupNextOperationSpec,
      callback
    ) as Promise<Models.ResourcesListByResourceGroupNextResponse>;
  }

  /**
   * Get all the resources in a subscription.
   * @param nextPageLink The NextLink from the previous successful call to List operation.
   * @param [options] The optional parameters
   * @returns Promise<Models.ResourcesListNextResponse>
   */
  listNext(
    nextPageLink: string,
    options?: Models.ResourcesListNextOptionalParams
  ): Promise<Models.ResourcesListNextResponse>;
  /**
   * @param nextPageLink The NextLink from the previous successful call to List operation.
   * @param callback The callback
   */
  listNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.ResourceListResult>): void;
  /**
   * @param nextPageLink The NextLink from the previous successful call to List operation.
   * @param options The optional parameters
   * @param callback The callback
   */
  listNext(
    nextPageLink: string,
    options: Models.ResourcesListNextOptionalParams,
    callback: msRest.ServiceCallback<Models.ResourceListResult>
  ): void;
  listNext(
    nextPageLink: string,
    options?:
      | Models.ResourcesListNextOptionalParams
      | msRest.ServiceCallback<Models.ResourceListResult>,
    callback?: msRest.ServiceCallback<Models.ResourceListResult>
  ): Promise<Models.ResourcesListNextResponse> {
    return this.client.sendOperationRequest(
      {
        nextPageLink,
        options
      },
      listNextOperationSpec,
      callback
    ) as Promise<Models.ResourcesListNextResponse>;
  }
}

// Operation Specifications
const serializer = new msRest.Serializer(Mappers);
const listByResourceGroupOperationSpec: msRest.OperationSpec = {
  httpMethod: "GET",
  path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/resources",
  urlParameters: [Parameters.resourceGroupName, Parameters.subscriptionId],
  queryParameters: [Parameters.filter, Parameters.expand, Parameters.top, Parameters.apiVersion],
  headerParameters: [Parameters.acceptLanguage],
  responses: {
    200: {
      bodyMapper: Mappers.ResourceListResult
    },
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const listOperationSpec: msRest.OperationSpec = {
  httpMethod: "GET",
  path: "subscriptions/{subscriptionId}/resources",
  urlParameters: [Parameters.subscriptionId],
  queryParameters: [Parameters.filter, Parameters.expand, Parameters.top, Parameters.apiVersion],
  headerParameters: [Parameters.acceptLanguage],
  responses: {
    200: {
      bodyMapper: Mappers.ResourceListResult
    },
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const checkExistenceOperationSpec: msRest.OperationSpec = {
  httpMethod: "HEAD",
  path:
    "subscriptions/{subscriptionId}/resourcegroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{parentResourcePath}/{resourceType}/{resourceName}",
  urlParameters: [
    Parameters.resourceGroupName,
    Parameters.resourceProviderNamespace,
    Parameters.parentResourcePath,
    Parameters.resourceType,
    Parameters.resourceName,
    Parameters.subscriptionId
  ],
  queryParameters: [Parameters.apiVersion],
  headerParameters: [Parameters.acceptLanguage],
  responses: {
    204: {},
    404: {},
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const getOperationSpec: msRest.OperationSpec = {
  httpMethod: "GET",
  path:
    "subscriptions/{subscriptionId}/resourcegroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{parentResourcePath}/{resourceType}/{resourceName}",
  urlParameters: [
    Parameters.resourceGroupName,
    Parameters.resourceProviderNamespace,
    Parameters.parentResourcePath,
    Parameters.resourceType,
    Parameters.resourceName,
    Parameters.subscriptionId
  ],
  queryParameters: [Parameters.apiVersion],
  headerParameters: [Parameters.acceptLanguage],
  responses: {
    200: {
      bodyMapper: Mappers.GenericResource
    },
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const checkExistenceByIdOperationSpec: msRest.OperationSpec = {
  httpMethod: "HEAD",
  path: "{resourceId}",
  urlParameters: [Parameters.resourceId],
  queryParameters: [Parameters.apiVersion],
  headerParameters: [Parameters.acceptLanguage],
  responses: {
    204: {},
    404: {},
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const getByIdOperationSpec: msRest.OperationSpec = {
  httpMethod: "GET",
  path: "{resourceId}",
  urlParameters: [Parameters.resourceId],
  queryParameters: [Parameters.apiVersion],
  headerParameters: [Parameters.acceptLanguage],
  responses: {
    200: {
      bodyMapper: Mappers.GenericResource
    },
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const beginMoveResourcesOperationSpec: msRest.OperationSpec = {
  httpMethod: "POST",
  path: "subscriptions/{subscriptionId}/resourceGroups/{sourceResourceGroupName}/moveResources",
  urlParameters: [Parameters.sourceResourceGroupName, Parameters.subscriptionId],
  queryParameters: [Parameters.apiVersion],
  headerParameters: [Parameters.acceptLanguage],
  requestBody: {
    parameterPath: "parameters",
    mapper: {
      ...Mappers.ResourcesMoveInfo,
      required: true
    }
  },
  responses: {
    202: {},
    204: {},
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const beginValidateMoveResourcesOperationSpec: msRest.OperationSpec = {
  httpMethod: "POST",
  path:
    "subscriptions/{subscriptionId}/resourceGroups/{sourceResourceGroupName}/validateMoveResources",
  urlParameters: [Parameters.sourceResourceGroupName, Parameters.subscriptionId],
  queryParameters: [Parameters.apiVersion],
  headerParameters: [Parameters.acceptLanguage],
  requestBody: {
    parameterPath: "parameters",
    mapper: {
      ...Mappers.ResourcesMoveInfo,
      required: true
    }
  },
  responses: {
    202: {},
    204: {},
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const beginDeleteMethodOperationSpec: msRest.OperationSpec = {
  httpMethod: "DELETE",
  path:
    "subscriptions/{subscriptionId}/resourcegroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{parentResourcePath}/{resourceType}/{resourceName}",
  urlParameters: [
    Parameters.resourceGroupName,
    Parameters.resourceProviderNamespace,
    Parameters.parentResourcePath,
    Parameters.resourceType,
    Parameters.resourceName,
    Parameters.subscriptionId
  ],
  queryParameters: [Parameters.apiVersion],
  headerParameters: [Parameters.acceptLanguage],
  responses: {
    200: {},
    202: {},
    204: {},
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const beginCreateOrUpdateOperationSpec: msRest.OperationSpec = {
  httpMethod: "PUT",
  path:
    "subscriptions/{subscriptionId}/resourcegroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{parentResourcePath}/{resourceType}/{resourceName}",
  urlParameters: [
    Parameters.resourceGroupName,
    Parameters.resourceProviderNamespace,
    Parameters.parentResourcePath,
    Parameters.resourceType,
    Parameters.resourceName,
    Parameters.subscriptionId
  ],
  queryParameters: [Parameters.apiVersion],
  headerParameters: [Parameters.acceptLanguage],
  requestBody: {
    parameterPath: "parameters",
    mapper: {
      ...Mappers.GenericResource,
      required: true
    }
  },
  responses: {
    200: {
      bodyMapper: Mappers.GenericResource
    },
    201: {
      bodyMapper: Mappers.GenericResource
    },
    202: {},
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const beginUpdateOperationSpec: msRest.OperationSpec = {
  httpMethod: "PATCH",
  path:
    "subscriptions/{subscriptionId}/resourcegroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{parentResourcePath}/{resourceType}/{resourceName}",
  urlParameters: [
    Parameters.resourceGroupName,
    Parameters.resourceProviderNamespace,
    Parameters.parentResourcePath,
    Parameters.resourceType,
    Parameters.resourceName,
    Parameters.subscriptionId
  ],
  queryParameters: [Parameters.apiVersion],
  headerParameters: [Parameters.acceptLanguage],
  requestBody: {
    parameterPath: "parameters",
    mapper: {
      ...Mappers.GenericResource,
      required: true
    }
  },
  responses: {
    200: {
      bodyMapper: Mappers.GenericResource
    },
    202: {},
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const beginDeleteByIdOperationSpec: msRest.OperationSpec = {
  httpMethod: "DELETE",
  path: "{resourceId}",
  urlParameters: [Parameters.resourceId],
  queryParameters: [Parameters.apiVersion],
  headerParameters: [Parameters.acceptLanguage],
  responses: {
    200: {},
    202: {},
    204: {},
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const beginCreateOrUpdateByIdOperationSpec: msRest.OperationSpec = {
  httpMethod: "PUT",
  path: "{resourceId}",
  urlParameters: [Parameters.resourceId],
  queryParameters: [Parameters.apiVersion],
  headerParameters: [Parameters.acceptLanguage],
  requestBody: {
    parameterPath: "parameters",
    mapper: {
      ...Mappers.GenericResource,
      required: true
    }
  },
  responses: {
    200: {
      bodyMapper: Mappers.GenericResource
    },
    201: {
      bodyMapper: Mappers.GenericResource
    },
    202: {},
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const beginUpdateByIdOperationSpec: msRest.OperationSpec = {
  httpMethod: "PATCH",
  path: "{resourceId}",
  urlParameters: [Parameters.resourceId],
  queryParameters: [Parameters.apiVersion],
  headerParameters: [Parameters.acceptLanguage],
  requestBody: {
    parameterPath: "parameters",
    mapper: {
      ...Mappers.GenericResource,
      required: true
    }
  },
  responses: {
    200: {
      bodyMapper: Mappers.GenericResource
    },
    202: {},
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const listByResourceGroupNextOperationSpec: msRest.OperationSpec = {
  httpMethod: "GET",
  baseUrl: "https://management.azure.com",
  path: "{nextLink}",
  urlParameters: [Parameters.nextPageLink],
  queryParameters: [Parameters.filter, Parameters.expand, Parameters.top, Parameters.apiVersion],
  headerParameters: [Parameters.acceptLanguage],
  responses: {
    200: {
      bodyMapper: Mappers.ResourceListResult
    },
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const listNextOperationSpec: msRest.OperationSpec = {
  httpMethod: "GET",
  baseUrl: "https://management.azure.com",
  path: "{nextLink}",
  urlParameters: [Parameters.nextPageLink],
  queryParameters: [Parameters.filter, Parameters.expand, Parameters.top, Parameters.apiVersion],
  headerParameters: [Parameters.acceptLanguage],
  responses: {
    200: {
      bodyMapper: Mappers.ResourceListResult
    },
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};
