import * as msRest from "@azure/ms-rest-js";
import * as Models from "../models";
import { StorageManagementClientContext } from "../storageManagementClientContext";
/** Class representing a ObjectReplicationPoliciesOperations. */
export declare class ObjectReplicationPoliciesOperations {
    private readonly client;
    /**
     * Create a ObjectReplicationPoliciesOperations.
     * @param {StorageManagementClientContext} client Reference to the service client.
     */
    constructor(client: StorageManagementClientContext);
    /**
     * List the object replication policies associated with the storage account.
     * @param resourceGroupName The name of the resource group within the user's subscription. The name
     * is case insensitive.
     * @param accountName The name of the storage account within the specified resource group. Storage
     * account names must be between 3 and 24 characters in length and use numbers and lower-case
     * letters only.
     * @param [options] The optional parameters
     * @returns Promise<Models.ObjectReplicationPoliciesListResponse>
     */
    list(resourceGroupName: string, accountName: string, options?: msRest.RequestOptionsBase): Promise<Models.ObjectReplicationPoliciesListResponse>;
    /**
     * @param resourceGroupName The name of the resource group within the user's subscription. The name
     * is case insensitive.
     * @param accountName The name of the storage account within the specified resource group. Storage
     * account names must be between 3 and 24 characters in length and use numbers and lower-case
     * letters only.
     * @param callback The callback
     */
    list(resourceGroupName: string, accountName: string, callback: msRest.ServiceCallback<Models.ObjectReplicationPolicies>): void;
    /**
     * @param resourceGroupName The name of the resource group within the user's subscription. The name
     * is case insensitive.
     * @param accountName The name of the storage account within the specified resource group. Storage
     * account names must be between 3 and 24 characters in length and use numbers and lower-case
     * letters only.
     * @param options The optional parameters
     * @param callback The callback
     */
    list(resourceGroupName: string, accountName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.ObjectReplicationPolicies>): void;
    /**
     * Get the object replication policy of the storage account by policy ID.
     * @param resourceGroupName The name of the resource group within the user's subscription. The name
     * is case insensitive.
     * @param accountName The name of the storage account within the specified resource group. Storage
     * account names must be between 3 and 24 characters in length and use numbers and lower-case
     * letters only.
     * @param objectReplicationPolicyId The ID of object replication policy or 'default' if the policy
     * ID is unknown.
     * @param [options] The optional parameters
     * @returns Promise<Models.ObjectReplicationPoliciesGetResponse>
     */
    get(resourceGroupName: string, accountName: string, objectReplicationPolicyId: string, options?: msRest.RequestOptionsBase): Promise<Models.ObjectReplicationPoliciesGetResponse>;
    /**
     * @param resourceGroupName The name of the resource group within the user's subscription. The name
     * is case insensitive.
     * @param accountName The name of the storage account within the specified resource group. Storage
     * account names must be between 3 and 24 characters in length and use numbers and lower-case
     * letters only.
     * @param objectReplicationPolicyId The ID of object replication policy or 'default' if the policy
     * ID is unknown.
     * @param callback The callback
     */
    get(resourceGroupName: string, accountName: string, objectReplicationPolicyId: string, callback: msRest.ServiceCallback<Models.ObjectReplicationPolicy>): void;
    /**
     * @param resourceGroupName The name of the resource group within the user's subscription. The name
     * is case insensitive.
     * @param accountName The name of the storage account within the specified resource group. Storage
     * account names must be between 3 and 24 characters in length and use numbers and lower-case
     * letters only.
     * @param objectReplicationPolicyId The ID of object replication policy or 'default' if the policy
     * ID is unknown.
     * @param options The optional parameters
     * @param callback The callback
     */
    get(resourceGroupName: string, accountName: string, objectReplicationPolicyId: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.ObjectReplicationPolicy>): void;
    /**
     * Create or update the object replication policy of the storage account.
     * @param resourceGroupName The name of the resource group within the user's subscription. The name
     * is case insensitive.
     * @param accountName The name of the storage account within the specified resource group. Storage
     * account names must be between 3 and 24 characters in length and use numbers and lower-case
     * letters only.
     * @param objectReplicationPolicyId The ID of object replication policy or 'default' if the policy
     * ID is unknown.
     * @param properties The object replication policy set to a storage account. A unique policy ID
     * will be created if absent.
     * @param [options] The optional parameters
     * @returns Promise<Models.ObjectReplicationPoliciesCreateOrUpdateResponse>
     */
    createOrUpdate(resourceGroupName: string, accountName: string, objectReplicationPolicyId: string, properties: Models.ObjectReplicationPolicy, options?: msRest.RequestOptionsBase): Promise<Models.ObjectReplicationPoliciesCreateOrUpdateResponse>;
    /**
     * @param resourceGroupName The name of the resource group within the user's subscription. The name
     * is case insensitive.
     * @param accountName The name of the storage account within the specified resource group. Storage
     * account names must be between 3 and 24 characters in length and use numbers and lower-case
     * letters only.
     * @param objectReplicationPolicyId The ID of object replication policy or 'default' if the policy
     * ID is unknown.
     * @param properties The object replication policy set to a storage account. A unique policy ID
     * will be created if absent.
     * @param callback The callback
     */
    createOrUpdate(resourceGroupName: string, accountName: string, objectReplicationPolicyId: string, properties: Models.ObjectReplicationPolicy, callback: msRest.ServiceCallback<Models.ObjectReplicationPolicy>): void;
    /**
     * @param resourceGroupName The name of the resource group within the user's subscription. The name
     * is case insensitive.
     * @param accountName The name of the storage account within the specified resource group. Storage
     * account names must be between 3 and 24 characters in length and use numbers and lower-case
     * letters only.
     * @param objectReplicationPolicyId The ID of object replication policy or 'default' if the policy
     * ID is unknown.
     * @param properties The object replication policy set to a storage account. A unique policy ID
     * will be created if absent.
     * @param options The optional parameters
     * @param callback The callback
     */
    createOrUpdate(resourceGroupName: string, accountName: string, objectReplicationPolicyId: string, properties: Models.ObjectReplicationPolicy, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.ObjectReplicationPolicy>): void;
    /**
     * Deletes the object replication policy associated with the specified storage account.
     * @param resourceGroupName The name of the resource group within the user's subscription. The name
     * is case insensitive.
     * @param accountName The name of the storage account within the specified resource group. Storage
     * account names must be between 3 and 24 characters in length and use numbers and lower-case
     * letters only.
     * @param objectReplicationPolicyId The ID of object replication policy or 'default' if the policy
     * ID is unknown.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    deleteMethod(resourceGroupName: string, accountName: string, objectReplicationPolicyId: string, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * @param resourceGroupName The name of the resource group within the user's subscription. The name
     * is case insensitive.
     * @param accountName The name of the storage account within the specified resource group. Storage
     * account names must be between 3 and 24 characters in length and use numbers and lower-case
     * letters only.
     * @param objectReplicationPolicyId The ID of object replication policy or 'default' if the policy
     * ID is unknown.
     * @param callback The callback
     */
    deleteMethod(resourceGroupName: string, accountName: string, objectReplicationPolicyId: string, callback: msRest.ServiceCallback<void>): void;
    /**
     * @param resourceGroupName The name of the resource group within the user's subscription. The name
     * is case insensitive.
     * @param accountName The name of the storage account within the specified resource group. Storage
     * account names must be between 3 and 24 characters in length and use numbers and lower-case
     * letters only.
     * @param objectReplicationPolicyId The ID of object replication policy or 'default' if the policy
     * ID is unknown.
     * @param options The optional parameters
     * @param callback The callback
     */
    deleteMethod(resourceGroupName: string, accountName: string, objectReplicationPolicyId: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
}
//# sourceMappingURL=objectReplicationPoliciesOperations.d.ts.map